@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,10 +15,18 @@
  */
 package org.kie.workbench.common.dmn.client.shape.def;
 
+import java.util.function.BiConsumer;
+
 import org.kie.workbench.common.dmn.api.definition.DMNDefinition;
+import org.kie.workbench.common.dmn.client.shape.view.handlers.DMNViewHandlers;
+import org.kie.workbench.common.stunner.shapes.client.view.ConnectorView;
 import org.kie.workbench.common.stunner.shapes.def.ConnectorShapeDef;
 
-public interface DMNConnectorShapeDef<W extends DMNDefinition> extends DMNShapeDef<W>,
-                                                                       ConnectorShapeDef<W> {
+public interface DMNConnectorShapeDef<W extends DMNDefinition, V extends ConnectorView> extends DMNShapeDef<W, V>,
+                                                                                                ConnectorShapeDef<W, V> {
 
+    @Override
+    default BiConsumer<W, V> viewHandler() {
+        return DMNViewHandlers.CONNECTOR_ATTRIBUTES_HANDLER::handle;
+    }
 }
