@@ -19,6 +19,7 @@ package org.kie.workbench.common.forms.processing.engine.handling.impl;
 import java.util.Collection;
 import java.util.Optional;
 import java.util.Set;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.inject.Default;
 import javax.inject.Inject;
@@ -83,7 +84,7 @@ public class DefaultModelValidator<MODEL> implements ModelValidator<MODEL> {
                     continue;
                 }
                 isValid = false;
-                formField.setError(constraintViolation.getMessage());
+                formField.showError(constraintViolation.getMessage());
             }
         } catch (IllegalArgumentException ex) {
             GWT.log("Error trying to validate model: model does not any validation constraint. ");
@@ -108,7 +109,7 @@ public class DefaultModelValidator<MODEL> implements ModelValidator<MODEL> {
 
                 if (checkBinding(formField,
                                  propertyName)) {
-                    formField.setError(constraintViolation.getMessage());
+                    formField.showError(constraintViolation.getMessage());
                     return false;
                 }
             }
