@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
+
 import javax.annotation.processing.Messager;
 import javax.annotation.processing.RoundEnvironment;
 import javax.annotation.processing.SupportedAnnotationTypes;
@@ -60,11 +61,12 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.field.selector
 import org.kie.workbench.common.forms.adf.definitions.annotations.i18n.I18nSettings;
 import org.kie.workbench.common.forms.adf.definitions.annotations.layout.Column;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldDefinition;
+import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldHelp;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldLabel;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldReadOnly;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldRequired;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldValue;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.LabelMode;
+import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.I18nMode;
 import org.kie.workbench.common.forms.adf.definitions.settings.ColSpan;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.forms.adf.processors.util.FormGenerationUtils;
@@ -273,7 +275,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                                         fieldInfo.getter);
                 }
 
-                if (fieldDefinitionAnnotation.labelMode().equals(LabelMode.OVERRIDE)) {
+                if (fieldDefinitionAnnotation.i18nMode().equals(I18nMode.OVERRIDE)) {
 
                     annotation = GeneratorUtils.getAnnotation(elementUtils,
                                                               fieldInfo.fieldElement,
@@ -294,6 +296,26 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                         templateContext.put("label",
                                             fieldInfo.getter);
                     }
+
+                    annotation = GeneratorUtils.getAnnotation(elementUtils,
+                                                              fieldInfo.fieldElement,
+                                                              FieldHelp.class.getName());
+
+                    if (annotation != null) {
+                        if (templateContext.containsKey("helpMessage")) {
+                            throw new Exception("Problem processing FieldDefinition [" + modelClassName + "]: it has more than one field marked as @FieldHelp");
+                        }
+
+                        if (!fieldInfo.fieldElement.asType().toString().equals(String.class.getName())) {
+                            throw new Exception("Problem processing FieldDefinition [" + modelClassName + "]: field marked as @FieldHelp must be a String");
+                        }
+
+                        if (fieldInfo.getter == null) {
+                            throw new Exception("Problem processing FieldDefinition [" + modelClassName + "]: field marked as @FieldHelp should have getter");
+                        }
+                        templateContext.put("helpMessage",
+                                            fieldInfo.getter);
+                    }
                 }
             }
         }
@@ -459,6 +481,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                 String fieldName = fieldInfo.fieldElement.getSimpleName().toString();
 
                 String fieldLabel = fieldName;
+                String helpMessage = "";
                 String binding = fieldName;
 
                 String methodName = "getFormElement_" + fieldName;
@@ -469,7 +492,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
 
                 org.kie.workbench.common.forms.model.TypeKind typeKind = org.kie.workbench.common.forms.model.TypeKind.BASE;
 
-                boolean overrideI18nLabel = false;
+                boolean overrideI18n = false;
 
                 TypeMirror finalType = fieldInfo.fieldElement.asType();
 
@@ -483,17 +506,26 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                         if (fieldDefinitionAnnotation != null) {
 
                             // Override the using the i18n mechanism
-                            if (fieldDefinitionAnnotation.labelMode().equals(LabelMode.OVERRIDE_I18N_KEY)) {
+                            if (fieldDefinitionAnnotation.i18nMode().equals(I18nMode.OVERRIDE_I18N_KEY)) {
+                                fieldLabel = finalType.toString() + i18nSettings.separator() + fieldDefinitionAnnotation.labelKeySuffix();
                                 Collection<FieldInfo> labelInfos = extractFieldInfos((TypeElement) finalTypeElement,
                                                                                      fieldElement -> fieldElement.getAnnotation(FieldLabel.class) != null);
 
-                                if (labelInfos == null || labelInfos.size() != 1) {
-                                    throw new Exception("Problem processing FieldDefinition [" + finalType + "]: it should have one field marked as @FieldLabel");
+                                if (labelInfos != null && labelInfos.size() == 1) {
+                                    FieldInfo labelInfo = labelInfos.iterator().next();
+                                    fieldLabel = finalType.toString() + i18nSettings.separator() + labelInfo.fieldElement.getSimpleName();
+
                                 }
 
-                                FieldInfo labelInfo = labelInfos.iterator().next();
+                                helpMessage = finalType.toString() + i18nSettings.separator() + fieldDefinitionAnnotation.helpMessageKeySuffix();
+                                Collection<FieldInfo> helpMessages = extractFieldInfos((TypeElement) finalTypeElement,
+                                                                                       fieldElement -> fieldElement.getAnnotation(FieldHelp.class) != null);
+
+                                if (helpMessages != null && helpMessages.size() == 1) {
+                                    FieldInfo helpInfo = helpMessages.iterator().next();
+                                    helpMessage = finalType.toString() + i18nSettings.separator() + helpInfo.fieldElement.getSimpleName();
+                                }
 
-                                fieldLabel = finalType.toString() + i18nSettings.separator() + labelInfo.fieldElement.getSimpleName();
                             }
 
                             Collection<FieldInfo> fieldValue = extractFieldInfos((TypeElement) finalTypeElement,
@@ -510,19 +542,31 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
 
                             finalType = valueInfo.getFieldElement().asType();
 
-                            overrideI18nLabel = !fieldDefinitionAnnotation.labelMode().equals(LabelMode.DONT_OVERRIDE);
+                            overrideI18n = !fieldDefinitionAnnotation.i18nMode().equals(I18nMode.DONT_OVERRIDE);
                         } else {
                             FormDefinition formDefinitionAnnotation = finalTypeElement.getAnnotation(FormDefinition.class);
 
                             if (formDefinitionAnnotation != null) {
+                                fieldLabel = finalType.toString() + i18nSettings.separator() + FieldDefinition.LABEL;
                                 Collection<FieldInfo> labelInfos = extractFieldInfos((TypeElement) finalTypeElement,
                                                                                      fieldElement -> fieldElement.getAnnotation(FieldLabel.class) != null);
 
-                                if (labelInfos != null & labelInfos.size() == 1) {
+                                if (labelInfos != null && labelInfos.size() == 1) {
                                     FieldInfo labelInfo = labelInfos.iterator().next();
                                     fieldLabel = finalType.toString() + i18nSettings.separator() + labelInfo.fieldElement.getSimpleName();
-                                    overrideI18nLabel = true;
+                                    overrideI18n = true;
                                 }
+
+                                helpMessage = finalType.toString() + i18nSettings.separator() + FieldDefinition.HELP_MESSAGE;
+                                Collection<FieldInfo> helpMessages = extractFieldInfos((TypeElement) finalTypeElement,
+                                                                                       fieldElement -> fieldElement.getAnnotation(FieldHelp.class) != null);
+
+                                if (helpMessages != null && helpMessages.size() == 1) {
+                                    FieldInfo helpInfo = helpMessages.iterator().next();
+                                    helpMessage = finalType.toString() + i18nSettings.separator() + helpInfo.fieldElement.getSimpleName();
+                                    overrideI18n = true;
+                                }
+
                                 typeKind = org.kie.workbench.common.forms.model.TypeKind.OBJECT;
                             }
                         }
@@ -582,9 +626,14 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
 
                     elementContext.put("preferredType",
                                        typeName);
-                    if (!overrideI18nLabel) {
+                    if (!overrideI18n && !isEmpty(settings.labelKey())) {
                         fieldLabel = settings.labelKey();
                     }
+
+                    if (!overrideI18n && !isEmpty(settings.helpMessageKey())) {
+                        helpMessage = settings.helpMessageKey();
+                    }
+
                     elementContext.put("required",
                                        Boolean.valueOf(settings.required()).toString());
                     elementContext.put("readOnly",
@@ -616,14 +665,17 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                                        "1");
                 }
 
-                if (!overrideI18nLabel) {
-                    if (!StringUtils.isEmpty(i18nSettings.keyPreffix())) {
+                if (!overrideI18n) {
+                    if (!isEmpty(i18nSettings.keyPreffix())) {
                         fieldLabel = i18nSettings.keyPreffix() + i18nSettings.separator() + fieldLabel;
+                        helpMessage = i18nSettings.keyPreffix() + i18nSettings.separator() + helpMessage;
                     }
                 }
 
                 elementContext.put("labelKey",
                                    fieldLabel);
+                elementContext.put("helpMessageKey",
+                                   helpMessage);
                 elementContext.put("afterElement",
                                    afterElement);
 
@@ -829,4 +881,8 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
     private TypeElement getParent(TypeElement classElement) {
         return (TypeElement) processingEnv.getTypeUtils().asElement(classElement.getSuperclass());
     }
+
+    private static final boolean isEmpty(final String s) {
+        return StringUtils.isEmpty(s);
+    }
 }
