@@ -21,6 +21,7 @@ import java.util.Iterator;
 
 import javax.annotation.PreDestroy;
 import javax.enterprise.context.Dependent;
+import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
@@ -41,11 +42,11 @@ import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
-import org.kie.workbench.common.forms.model.FormModel;
 import org.kie.workbench.common.services.refactoring.client.usages.ShowAssetUsagesDisplayer;
 import org.kie.workbench.common.services.refactoring.service.ResourceType;
 import org.kie.workbench.common.widgets.metadata.client.KieEditor;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorView;
+import org.kie.workbench.common.workbench.client.events.LayoutEditorFocusEvent;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.annotations.WorkbenchEditor;
@@ -58,6 +59,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
 import org.uberfire.ext.layout.editor.client.api.ComponentRemovedEvent;
 import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentGroup;
+import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentPalette;
 import org.uberfire.ext.layout.editor.client.api.LayoutEditor;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
@@ -72,9 +74,11 @@ import org.uberfire.workbench.model.menu.Menus;
 import org.uberfire.workbench.type.FileNameUtil;
 
 @Dependent
-@WorkbenchEditor(identifier = "FormEditor", supportedTypes = {FormDefinitionResourceType.class})
+@WorkbenchEditor(identifier = FormEditorPresenter.ID, supportedTypes = {FormDefinitionResourceType.class})
 public class FormEditorPresenter extends KieEditor {
 
+    public static final String ID = "FormEditor";
+
     @Inject
     protected LayoutEditor layoutEditor;
     @Inject
@@ -82,25 +86,32 @@ public class FormEditorPresenter extends KieEditor {
     @Inject
     protected BusyIndicatorView busyIndicatorView;
     @Inject
+    protected FormEditorContext formEditorContext;
+    @Inject
     protected FormEditorHelper editorHelper;
     protected ManagedInstance<EditorFieldLayoutComponent> editorFieldLayoutComponents;
     @Inject
     private Caller<MetadataService> metadataService;
+    @Inject
+    protected LayoutDragComponentPalette layoutDragComponentPalette;
+    @Inject
+    protected Event<LayoutEditorFocusEvent> layoutFocusEvent;
     private ShowAssetUsagesDisplayer showAssetUsagesDisplayer;
     private FormEditorView view;
     private ChangesNotificationDisplayer changesNotificationDisplayer;
     private FormDefinitionResourceType resourceType;
     private Caller<FormEditorService> editorService;
     private TranslationService translationService;
+    protected boolean setActiveOnLoad = false;
 
     @Inject
     public FormEditorPresenter(FormEditorView view,
-                               ChangesNotificationDisplayer changesNotificationDisplayer,
-                               FormDefinitionResourceType resourceType,
-                               Caller<FormEditorService> editorService,
-                               TranslationService translationService,
-                               ManagedInstance<EditorFieldLayoutComponent> editorFieldLayoutComponents,
-                               ShowAssetUsagesDisplayer showAssetUsagesDisplayer) {
+            ChangesNotificationDisplayer changesNotificationDisplayer,
+            FormDefinitionResourceType resourceType,
+            Caller<FormEditorService> editorService,
+            TranslationService translationService,
+            ManagedInstance<EditorFieldLayoutComponent> editorFieldLayoutComponents,
+            ShowAssetUsagesDisplayer showAssetUsagesDisplayer) {
         super(view);
         this.view = view;
         this.changesNotificationDisplayer = changesNotificationDisplayer;
@@ -113,16 +124,28 @@ public class FormEditorPresenter extends KieEditor {
 
     @OnStartup
     public void onStartup(final ObservablePath path,
-                          final PlaceRequest place) {
+            final PlaceRequest place) {
 
         init(path,
-             place,
-             resourceType);
+                place,
+                resourceType);
     }
 
     @OnFocus
     public void onFocus() {
-        FormEditorContext.get().setActiveEditorHelper(editorHelper);
+        if(editorHelper.getContent() == null) {
+            this.setActiveOnLoad = true;
+        } else {
+            setActiveInstance();
+        }
+    }
+
+    private void setActiveInstance() {
+        formEditorContext.setActiveEditorHelper(editorHelper);
+
+        initLayoutDragComponentPalette();
+
+        layoutFocusEvent.fire(new LayoutEditorFocusEvent());
     }
 
     @Override
@@ -175,20 +198,21 @@ public class FormEditorPresenter extends KieEditor {
         view.setupLayoutEditor(layoutEditor);
 
         changesNotificationDisplayer.show(content,
-                                          this::synchronizeLayoutEditor);
+                this::synchronizeLayoutEditor);
+
+        if(setActiveOnLoad) {
+            setActiveInstance();
+            setActiveOnLoad = false;
+        }
     }
 
     protected void loadLayoutEditor() {
         layoutEditor.clear();
 
-        loadAvailableFields();
-
         layoutEditor.init(editorHelper.getContent().getDefinition().getName(),
-                          getLayoutComponent(),
-                          translationService
-                                  .getTranslation(FormEditorConstants.FormEditorPresenterLayoutTitle),
-                          translationService
-                                  .getTranslation(FormEditorConstants.FormEditorPresenterLayoutSubTitle));
+                translationService.getTranslation(FormEditorConstants.FormEditorPresenterLayoutTitle),
+                translationService.getTranslation(FormEditorConstants.FormEditorPresenterLayoutSubTitle),
+                LayoutTemplate.Style.FLUID);
 
         layoutEditor.loadLayout(editorHelper.getContent().getDefinition().getLayoutTemplate());
     }
@@ -199,15 +223,18 @@ public class FormEditorPresenter extends KieEditor {
         }
     }
 
-    protected LayoutDragComponentGroup getLayoutComponent() {
+    protected void initLayoutDragComponentPalette() {
+        layoutDragComponentPalette.clear();
+
+        loadAvailableFields();
+        loadFormControls();
+    }
+
+    protected void loadFormControls() {
         LayoutDragComponentGroup group = new LayoutDragComponentGroup(translationService.getTranslation(FormEditorConstants.FormEditorPresenterComponentsPalette));
-        group.addLayoutDragComponent("html",
-                                     htmlLayoutDragComponent);
-
-        editorHelper.getBaseFieldsDraggables().forEach(component -> group.addLayoutDragComponent(component.getFieldId(),
-                                                                                                 component));
-
-        return group;
+        group.addLayoutDragComponent("html", htmlLayoutDragComponent);
+        editorHelper.getBaseFieldsDraggables().forEach(component -> group.addLayoutDragComponent(component.getFieldId(), component));
+        layoutDragComponentPalette.addDraggableGroup(group);
     }
 
     @Override
@@ -237,9 +264,9 @@ public class FormEditorPresenter extends KieEditor {
     protected void makeMenuBar() {
         if (canUpdateProject()) {
             fileMenuBuilder
-                    .addSave(versionRecordManager.newSaveMenuItem(() -> onSave()))
+                    .addSave(versionRecordManager.newSaveMenuItem(() -> saveAction()))
                     .addCopy(versionRecordManager.getCurrentPath(),
-                             fileNameValidator)
+                             assetUpdateValidator)
                     .addRename(this::safeRename)
                     .addDelete(this::safeDelete);
         }
@@ -266,19 +293,21 @@ public class FormEditorPresenter extends KieEditor {
     }
 
     public void rename(boolean save) {
-        if(save) {
+        if (save) {
             synchronizeFormLayout();
         }
         renamePopUpPresenter.show(versionRecordManager.getPathToLatest(),
-                                  fileNameValidator,
+                                  assetUpdateValidator,
                                   getRenameCommand(save));
     }
 
     protected CommandWithFileNameAndCommitMessage getRenameCommand(boolean save) {
-        return details -> renameCommand(details, save);
+        return details -> renameCommand(details,
+                                        save);
     }
 
-    protected void renameCommand(FileNameAndCommitMessage details, boolean save) {
+    protected void renameCommand(FileNameAndCommitMessage details,
+                                 boolean save) {
         view.showBusyIndicator(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.Renaming());
 
         editorService.call(getRenameSuccessCallback(renamePopUpPresenter.getView()),
@@ -322,9 +351,7 @@ public class FormEditorPresenter extends KieEditor {
     }
 
     protected void loadAvailableFields() {
-        FormModel model = editorHelper.getFormDefinition().getModel();
-
-        LayoutDragComponentGroup group = new LayoutDragComponentGroup(model.getName());
+        LayoutDragComponentGroup group = new LayoutDragComponentGroup(translationService.getTranslation(FormEditorConstants.FormEditorPresenterModelFields));
 
         editorHelper.getAvailableFields().values().forEach(fieldDefinition -> {
             EditorFieldLayoutComponent layoutFieldComponent = editorFieldLayoutComponents.get();
@@ -336,11 +363,11 @@ public class FormEditorPresenter extends KieEditor {
             }
         });
 
-        layoutEditor.addDraggableComponentGroup(group);
+        layoutDragComponentPalette.addDraggableGroup(group);
     }
 
     public void onRemoveComponent(@Observes ComponentRemovedEvent event) {
-        if (editorHelper == null || editorHelper.getContent() == null) {
+        if (editorHelper == null || editorHelper.getContent() == null || event.getLayoutComponent() == null) {
             return;
         }
 
@@ -348,26 +375,31 @@ public class FormEditorPresenter extends KieEditor {
 
         if (editorHelper.getFormDefinition().getId().equals(formId)) {
             String fieldId = event.getLayoutComponent().getProperties().get(FieldLayoutComponent.FIELD_ID);
-            editorHelper.removeField(fieldId,
-                                     true);
-            onSyncPalette(formId);
+
+            // If the event is caused by a element move we must hold the field on the form.
+            // If not it means that it should be removed.
+            if(!event.getFromMove()) {
+                editorHelper.removeField(fieldId,
+                                         true);
+                onSyncPalette(formId);
+            }
         }
     }
 
     protected void removeAllDraggableGroupComponent(Collection<FieldDefinition> fields) {
-        String groupId = getFormDefinition().getModel().getName();
+        String groupId = translationService.getTranslation(FormEditorConstants.FormEditorPresenterModelFields);
         Iterator<FieldDefinition> it = fields.iterator();
         while (it.hasNext()) {
             FieldDefinition field = it.next();
-            if (layoutEditor.hasDraggableGroupComponent(groupId,
-                                                        field.getId())) {
-                layoutEditor.removeDraggableGroupComponent(groupId,
-                                                           field.getId());
+            if (layoutDragComponentPalette.hasDraggableComponent(groupId, field.getId())) {
+                layoutDragComponentPalette.removeDraggableComponent(groupId, field.getId());
             }
         }
     }
 
     protected void addAllDraggableGroupComponent(Collection<FieldDefinition> fields) {
+        String groupId = translationService.getTranslation(FormEditorConstants.FormEditorPresenterModelFields);
+
         Iterator<FieldDefinition> it = fields.iterator();
         while (it.hasNext()) {
             FieldDefinition field = it.next();
@@ -376,9 +408,9 @@ public class FormEditorPresenter extends KieEditor {
             if (layoutFieldComponent != null) {
                 layoutFieldComponent.init(editorHelper.getRenderingContext(),
                                           field);
-                layoutEditor.addDraggableComponentToGroup(getFormDefinition().getModel().getName(),
-                                                          field.getId(),
-                                                          layoutFieldComponent);
+                layoutDragComponentPalette.addDraggableComponent(groupId,
+                                                 field.getId(),
+                                                 layoutFieldComponent);
             }
         }
     }
@@ -410,15 +442,16 @@ public class FormEditorPresenter extends KieEditor {
     }
 
     private void onDelete(ObservablePath pathToLatest) {
-        deletePopUpPresenter.show(comment -> {
-            view.showBusyIndicator(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.Deleting());
-            editorService.call(response -> {
-                view.hideBusyIndicator();
-                notification.fire(new NotificationEvent(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.ItemDeletedSuccessfully(),
-                                                        NotificationEvent.NotificationType.SUCCESS));
-            }).delete(pathToLatest,
-                      comment);
-        });
+        deletePopUpPresenter.show(assetUpdateValidator,
+                                  comment -> {
+                                      view.showBusyIndicator(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.Deleting());
+                                      editorService.call(response -> {
+                                          view.hideBusyIndicator();
+                                          notification.fire(new NotificationEvent(org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants.INSTANCE.ItemDeletedSuccessfully(),
+                                                                                  NotificationEvent.NotificationType.SUCCESS));
+                                      }).delete(pathToLatest,
+                                                comment);
+                                  });
     }
 
     @OnMayClose
