@@ -36,22 +36,18 @@ import org.kie.workbench.common.forms.editor.client.type.FormDefinitionResourceT
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.editor.model.impl.FormModelSynchronizationResultImpl;
 import org.kie.workbench.common.forms.editor.service.shared.FormEditorService;
-import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.checkBox.definition.CheckBoxFieldDefinition;
-import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.datePicker.definition.DatePickerFieldDefinition;
-import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.TextBoxFieldDefinition;
 import org.kie.workbench.common.forms.fields.test.TestFieldManager;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
 import org.kie.workbench.common.forms.model.ModelProperty;
-import org.kie.workbench.common.forms.model.impl.ModelPropertyImpl;
 import org.kie.workbench.common.forms.model.impl.PortableJavaModel;
-import org.kie.workbench.common.forms.model.impl.TypeInfoImpl;
 import org.kie.workbench.common.services.refactoring.client.usages.ShowAssetUsagesDisplayer;
 import org.kie.workbench.common.services.refactoring.client.usages.ShowAssetUsagesDisplayerView;
 import org.kie.workbench.common.services.refactoring.service.AssetsUsageService;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.workbench.client.events.LayoutEditorFocusEvent;
 import org.mockito.Mock;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
@@ -62,6 +58,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.commons.ToggleCommentP
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.layout.editor.api.editor.LayoutTemplate;
+import org.uberfire.ext.layout.editor.client.api.LayoutDragComponentPalette;
 import org.uberfire.ext.layout.editor.client.api.LayoutEditor;
 import org.uberfire.ext.plugin.client.perspective.editor.layout.editor.HTMLLayoutDragComponent;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
@@ -73,9 +70,12 @@ import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 public class FormEditorPresenterAbstractTest {
 
@@ -114,6 +114,12 @@ public class FormEditorPresenterAbstractTest {
     @Mock
     protected LayoutEditor layoutEditorMock;
 
+    @Mock
+    protected LayoutDragComponentPalette layoutDragComponentPaletteMock;
+
+    @Mock
+    protected EventSourceMock<LayoutEditorFocusEvent> layoutFocusEventMock;
+
     @Mock
     protected HTMLLayoutDragComponent htmlLayoutDragComponent;
 
@@ -248,6 +254,8 @@ public class FormEditorPresenterAbstractTest {
                 busyIndicatorView = mock(BusyIndicatorView.class);
                 overviewWidget = mock(OverviewWidgetPresenter.class);
                 layoutEditor = layoutEditorMock;
+                layoutDragComponentPalette = layoutDragComponentPaletteMock;
+                layoutFocusEvent = layoutFocusEventMock;
                 htmlLayoutDragComponent = FormEditorPresenterAbstractTest.this.htmlLayoutDragComponent;
                 notification = notificationEvent;
                 fileMenuBuilder = menuBuilderMock;
@@ -255,6 +263,7 @@ public class FormEditorPresenterAbstractTest {
                 projectController = FormEditorPresenterAbstractTest.this.projectController;
                 deletePopUpPresenter = FormEditorPresenterAbstractTest.this.deletePopUpPresenter;
                 renamePopUpPresenter = FormEditorPresenterAbstractTest.this.renamePopUpPresenter;
+                formEditorContext = mock(FormEditorContext.class);
             }
 
             @Override
