@@ -25,11 +25,13 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldLayoutComponent;
 import org.kie.workbench.common.forms.editor.client.editor.events.FormEditorSyncPaletteEvent;
+import org.kie.workbench.common.forms.editor.client.resources.i18n.FormEditorConstants;
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.definition.TextAreaFieldDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textBox.definition.TextBoxFieldDefinition;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormDefinition;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.mockito.verification.VerificationMode;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
@@ -56,6 +58,7 @@ import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
@@ -77,12 +80,14 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     public void testLoadWithContent() {
         testLoad();
 
+        reset(layoutDragComponentPaletteMock);
         FormEditorPresenter presenterSpy = spy(presenter);
+        presenterSpy.setActiveOnLoad = true;
         presenterSpy.loadContent();
 
         verify(presenterSpy).loadAvailableFields();
-        verify(layoutEditorMock,
-               times(2)).addDraggableComponentGroup(any());
+        verify(layoutDragComponentPaletteMock,
+               times(2)).addDraggableGroup(any());
 
         verify(layoutEditorMock,
                times(3)).clear();
@@ -231,7 +236,8 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
                                                                 FieldDefinition field) {
 
         return new ComponentRemovedEvent(createLayoutComponent(form,
-                                                               field));
+                                                               field),
+                                         false);
     }
 
     protected LayoutComponent createLayoutComponent(FormDefinition form,
@@ -310,15 +316,18 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     public void testRemoveAllDraggableGroupComponent() {
         loadContent();
         addAllFields();
-        when(layoutEditorMock.hasDraggableGroupComponent(anyString(),
+        when(layoutDragComponentPaletteMock.hasDraggableComponent(anyString(),
                                                          anyString())).thenReturn(true);
         List<FieldDefinition> fieldList = presenter.getFormDefinition().getFields();
 
         presenter.removeAllDraggableGroupComponent(fieldList);
 
-        verify(layoutEditorMock,
-               times(fieldList.size())).removeDraggableGroupComponent(anyString(),
-                                                                      anyString());
+        verify(translationService,
+               times(1)).getTranslation(FormEditorConstants.FormEditorPresenterModelFields);
+
+        verify(layoutDragComponentPaletteMock,
+               times(fieldList.size())).removeDraggableComponent(anyString(),
+                                                        anyString());
     }
 
     @Test
@@ -327,10 +336,10 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         List<FieldDefinition> fieldList = presenter.getFormDefinition().getFields();
         presenter.addAllDraggableGroupComponent(fieldList);
-        verify(layoutEditorMock,
-               times(fieldList.size())).addDraggableComponentToGroup(anyString(),
-                                                                     anyString(),
-                                                                     any());
+        verify(layoutDragComponentPaletteMock,
+               times(fieldList.size())).addDraggableComponent(anyString(),
+                                                    anyString(),
+                                                    any());
     }
 
     @Test
@@ -357,7 +366,8 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         FieldDefinition field = editorHelper.getFormDefinition().getFields().get(0);
 
         ComponentRemovedEvent event = new ComponentRemovedEvent(createLayoutComponent(presenter.getFormDefinition(),
-                                                                                      field));
+                                                                                      field),
+                                                                false);
         presenterSpy.onRemoveComponent(event);
 
         verify(presenterSpy,
@@ -367,6 +377,48 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
                                   anyBoolean());
     }
 
+    @Test
+    public void testOnRemoveComponentWithoutLayoutComponent() {
+        loadContent();
+        loadAvailableFields();
+        addAllFields();
+
+        FormEditorPresenter presenterSpy = spy(presenter);
+
+        ComponentRemovedEvent event = new ComponentRemovedEvent(null);
+        presenterSpy.onRemoveComponent(event);
+
+        verify(presenterSpy,
+               never()).onSyncPalette(anyString());
+        verify(editorHelper,
+               never()).removeField(anyString(),
+                                    anyBoolean());
+    }
+
+    @Test
+    public void testRemoveEventWhenMovingFieldOnLayout() {
+        loadContent();
+        loadAvailableFields();
+        addAllFields();
+
+        FormEditorPresenter presenterSpy = spy(presenter);
+
+        FieldDefinition field = editorHelper.getFormDefinition().getFields().get(0);
+
+        ComponentRemovedEvent event = new ComponentRemovedEvent(createLayoutComponent(presenter.getFormDefinition(),
+                                                                                      field),
+                                                                true);
+        presenterSpy.onRemoveComponent(event);
+
+        assertNotNull(editorHelper.getFormDefinition().getFieldById(field.getId()));
+
+        verify(presenterSpy,
+               never()).onSyncPalette(anyString());
+        verify(editorHelper,
+               never()).removeField(anyString(),
+                                    anyBoolean());
+    }
+
     @Test
     public void testDestroy() {
         loadContent();
@@ -414,7 +466,7 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         verify(menuBuilderMock).addSave(any(MenuItem.class));
         verify(menuBuilderMock).addCopy(any(Path.class),
-                                        any(DefaultFileNameValidator.class));
+                                        any(AssetUpdateValidator.class));
         verify(menuBuilderMock).addRename(any(Command.class));
         verify(menuBuilderMock).addDelete(any(Command.class));
 
@@ -434,12 +486,13 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
                never()).addSave(any(MenuItem.class));
         verify(menuBuilderMock,
                never()).addCopy(any(Path.class),
-                                any(DefaultFileNameValidator.class));
+                                any(AssetUpdateValidator.class));
         verify(menuBuilderMock,
                never()).addRename(any(Path.class),
-                                  any(DefaultFileNameValidator.class));
+                                  any(AssetUpdateValidator.class));
         verify(menuBuilderMock,
-               never()).addDelete(any(Path.class));
+               never()).addDelete(any(Path.class),
+                                  any(AssetUpdateValidator.class));
 
         assertNotNull(presenter.getMenus());
         verify(menuBuilderMock,
@@ -452,13 +505,20 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         presenter.safeDelete();
 
-        verify(showAssetUsagesDisplayer).showAssetUsages(anyString(), any(), any(), any(), any(), any());
+        verify(showAssetUsagesDisplayer).showAssetUsages(anyString(),
+                                                         any(),
+                                                         any(),
+                                                         any(),
+                                                         any(),
+                                                         any());
 
-        verify(deletePopUpPresenter).show(any());
+        verify(deletePopUpPresenter).show(any(AssetUpdateValidator.class),
+                                          any());
 
         deletePopUpPresenter.delete();
 
-        verify(formEditorService).delete(any(), any());
+        verify(formEditorService).delete(any(),
+                                         any());
         verify(view).hideBusyIndicator();
         verify(notificationEvent).fire(any());
     }
@@ -471,46 +531,65 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
 
         presenter.safeDelete();
 
-        verify(showAssetUsagesDisplayer).showAssetUsages(anyString(), any(), any(), any(), any(), any());
+        verify(showAssetUsagesDisplayer).showAssetUsages(anyString(),
+                                                         any(),
+                                                         any(),
+                                                         any(),
+                                                         any(),
+                                                         any());
 
-        verify(deletePopUpPresenter, never()).show(any());
+        verify(deletePopUpPresenter,
+               never()).show(any());
 
         showAssetUsagesDisplayer.onOk();
         showAssetUsagesDisplayer.onClose();
 
-        verify(deletePopUpPresenter).show(any());
+        verify(deletePopUpPresenter).show(any(AssetUpdateValidator.class),
+                                          any());
 
         deletePopUpPresenter.delete();
 
-        verify(formEditorService).delete(any(), any());
+        verify(formEditorService).delete(any(),
+                                         any());
         verify(view).hideBusyIndicator();
         verify(notificationEvent).fire(any());
     }
 
     @Test
     public void testSafeRenameDirtySaving() {
-        FormEditorPresenter presenterSpy = triggerSafeRename(true, true);
-        verify(view).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        FormEditorPresenter presenterSpy = triggerSafeRename(true,
+                                                             true);
+        verify(view).showSavePopup(any(Path.class),
+                                   any(Command.class),
+                                   any(Command.class));
         verify(presenterSpy).rename(eq(true));
     }
 
     @Test
     public void testSafeRenameDirtyNotSaving() {
-        FormEditorPresenter presenterSpy = triggerSafeRename(true, false);
+        FormEditorPresenter presenterSpy = triggerSafeRename(true,
+                                                             false);
 
-        verify(view).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        verify(view).showSavePopup(any(Path.class),
+                                   any(Command.class),
+                                   any(Command.class));
         verify(presenterSpy).rename(eq(false));
     }
 
     @Test
     public void testSafeRenameNotDirty() {
-        FormEditorPresenter presenterSpy = triggerSafeRename(false, false);
+        FormEditorPresenter presenterSpy = triggerSafeRename(false,
+                                                             false);
 
-        verify(view, never()).showSavePopup(any(Path.class), any(Command.class), any(Command.class));
+        verify(view,
+               never()).showSavePopup(any(Path.class),
+                                      any(Command.class),
+                                      any(Command.class));
         verify(presenterSpy).rename(eq(false));
     }
 
-    private FormEditorPresenter triggerSafeRename(boolean dirty, boolean saving) {
+    private FormEditorPresenter triggerSafeRename(boolean dirty,
+                                                  boolean saving) {
         loadContent();
         FormEditorPresenter presenterSpy = spy(presenter);
         doNothing().when(presenterSpy).rename(anyBoolean());
@@ -537,7 +616,9 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
     private void testRename(boolean saving) {
         loadContent();
         presenter.rename(saving);
-        verify(renamePopUpPresenter).show(any(Path.class), any(DefaultFileNameValidator.class), any(CommandWithFileNameAndCommitMessage.class));
+        verify(renamePopUpPresenter).show(any(Path.class),
+                                          any(DefaultFileNameValidator.class),
+                                          any(CommandWithFileNameAndCommitMessage.class));
     }
 
     @Test
@@ -548,7 +629,8 @@ public class FormEditorPresenterTest extends FormEditorPresenterAbstractTest {
         when(renamePopUpPresenter.getView()).thenReturn(mock(RenamePopUpPresenter.View.class));
         doNothing().when(presenterSpy).doLoadContent(any(FormModelerContent.class));
 
-        presenterSpy.renameCommand(details, true);
+        presenterSpy.renameCommand(details,
+                                   true);
 
         verify(view).showBusyIndicator(anyString());
         verify(presenterSpy).getRenameErrorCallback(any(RenamePopUpPresenter.View.class));
