@@ -65,9 +65,13 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.uberfire.backend.vfs.Path;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class DataObjectFormModelHandlerTest extends AbstractDataObjectTest {
@@ -237,7 +241,7 @@ public class DataObjectFormModelHandlerTest extends AbstractDataObjectTest {
         formModel = handler.createFormModel(dataObject, path);
 
         SubFormFieldDefinition subForm = (SubFormFieldDefinition) checkCommonProperties("address");
-        assertEquals("",
+        assertEquals(null,
                      subForm.getNestedForm());
     }
 
@@ -246,9 +250,9 @@ public class DataObjectFormModelHandlerTest extends AbstractDataObjectTest {
         formModel = handler.createFormModel(dataObject, path);
 
         MultipleSubFormFieldDefinition multipleSubform = (MultipleSubFormFieldDefinition) checkCommonProperties("address_list");
-        assertEquals("",
+        assertEquals(null,
                      multipleSubform.getCreationForm());
-        assertEquals("",
+        assertEquals(null,
                      multipleSubform.getEditionForm());
         assertEquals(Collections.emptyList(),
                      multipleSubform.getColumnMetas());
