@@ -17,9 +17,10 @@
 package org.kie.workbench.common.forms.jbpm.server.service.formGeneration.impl.runtime;
 
 import org.junit.Before;
+import org.kie.soup.project.datamodel.commons.util.RawMVELEvaluator;
 import org.kie.workbench.common.forms.jbpm.server.service.formGeneration.impl.AbstractBPMNFormGeneratorServiceTest;
 
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
 
 public abstract class BPMNRuntimeFormDefinitionGeneratorServiceTest extends AbstractBPMNFormGeneratorServiceTest<BPMNRuntimeFormGeneratorService, ClassLoader> {
 
@@ -28,6 +29,7 @@ public abstract class BPMNRuntimeFormDefinitionGeneratorServiceTest extends Abst
 
         source = mock(ClassLoader.class);
 
-        service = new BPMNRuntimeFormGeneratorService(fieldManager);
+        service = new BPMNRuntimeFormGeneratorService(fieldManager,
+                                                      new RawMVELEvaluator());
     }
 }
