@@ -23,13 +23,18 @@ import org.guvnor.common.services.project.model.Project;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
 import org.guvnor.messageconsole.events.PublishBatchMessagesEvent;
 import org.guvnor.messageconsole.events.UnpublishMessagesEvent;
+import org.junit.Before;
 import org.junit.Test;
 import org.kie.workbench.common.screens.datamodeller.client.context.DataModelerWorkbenchFocusEvent;
-import org.kie.workbench.common.screens.datamodeller.client.validation.JavaFileNameValidator;
 import org.kie.workbench.common.screens.datamodeller.model.EditorModelContent;
 import org.kie.workbench.common.services.datamodeller.core.DataObject;
+import org.kie.workbench.common.widgets.metadata.client.validation.JavaAssetUpdateValidator;
+import org.mockito.ArgumentCaptor;
+import org.mockito.Mock;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
+import org.uberfire.ext.editor.commons.client.file.FileNameAndCommitMessage;
+import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
 import org.uberfire.ext.editor.commons.client.validation.Validator;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.ParameterizedCommand;
@@ -41,6 +46,31 @@ import static org.mockito.Mockito.*;
 public class DataModelerScreenPresenterTest
         extends DataModelerScreenPresenterTestBase {
 
+    private static final String FILE_NAME = "FILE_NAME";
+
+    private static final String COMMIT_MESSAGE = "COMMIT_MESSAGE";
+
+    private ArgumentCaptor<Path> pathArgumentCaptor;
+
+    private ArgumentCaptor<Validator> validatorArgumentCaptor;
+
+    private ArgumentCaptor<CommandWithFileNameAndCommitMessage> commandWithFileNameArgumentCaptor;
+
+    @Mock
+    private FileNameAndCommitMessage commitMessage;
+
+    @Mock
+    protected CopyPopUpPresenter.View copyPopUpPresenterView;
+
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
+        when(copyPopUpPresenter.getView()).thenReturn(copyPopUpPresenterView);
+        pathArgumentCaptor = ArgumentCaptor.forClass(Path.class);
+        validatorArgumentCaptor = ArgumentCaptor.forClass(Validator.class);
+        commandWithFileNameArgumentCaptor = ArgumentCaptor.forClass(CommandWithFileNameAndCommitMessage.class);
+    }
+
     /**
      * This test emulates the loading of a java file that was parsed without errors.
      * Additionally it supposes that the DataModelerWBContext has not yet the information about property types
@@ -378,7 +408,8 @@ public class DataModelerScreenPresenterTest
                                         any());
         verify(validationService).validateForDelete(any(),
                                                     any());
-        verify(deletePopUpPresenter).show(any());
+        verify(deletePopUpPresenter).show(any(JavaAssetUpdateValidator.class),
+                                          any());
     }
 
     @Test
@@ -394,8 +425,10 @@ public class DataModelerScreenPresenterTest
                                                 any(),
                                                 any());
 
-        verify(renamePopUpPresenter, never()).show(any(Path.class), any(Validator.class), any(CommandWithFileNameAndCommitMessage.class));
-
+        verify(renamePopUpPresenter,
+               never()).show(any(Path.class),
+                             any(JavaAssetUpdateValidator.class),
+                             any(CommandWithFileNameAndCommitMessage.class));
     }
 
     @Test
@@ -406,14 +439,17 @@ public class DataModelerScreenPresenterTest
 
         presenter.onSafeRename();
 
-        verify(showAssetUsages, never()).showAssetUsages(anyString(),
-                                                any(),
-                                                anyString(),
-                                                any(),
-                                                any(),
-                                                any());
+        verify(showAssetUsages,
+               never()).showAssetUsages(anyString(),
+                                        any(),
+                                        anyString(),
+                                        any(),
+                                        any(),
+                                        any());
 
-        verify(renamePopUpPresenter).show(any(Path.class), any(Validator.class), any(CommandWithFileNameAndCommitMessage.class));
+        verify(renamePopUpPresenter).show(any(Path.class),
+                                          any(JavaAssetUpdateValidator.class),
+                                          any(CommandWithFileNameAndCommitMessage.class));
     }
 
     @Test
@@ -435,7 +471,7 @@ public class DataModelerScreenPresenterTest
 
         verify(renamePopUpPresenter,
                times(1)).show(any(Path.class),
-                              any(JavaFileNameValidator.class),
+                              any(JavaAssetUpdateValidator.class),
                               any(CommandWithFileNameAndCommitMessage.class));
         verify(validationPopup,
                never()).showSaveValidationMessages(any(Command.class),
@@ -462,7 +498,7 @@ public class DataModelerScreenPresenterTest
 
         verify(renamePopUpPresenter,
                never()).show(any(Path.class),
-                             any(JavaFileNameValidator.class),
+                             any(JavaAssetUpdateValidator.class),
                              any(CommandWithFileNameAndCommitMessage.class));
         verify(validationPopup,
                times(1)).showSaveValidationMessages(any(Command.class),
@@ -480,7 +516,7 @@ public class DataModelerScreenPresenterTest
 
         verify(copyPopUpPresenter,
                times(1)).show(any(Path.class),
-                              any(JavaFileNameValidator.class),
+                              any(JavaAssetUpdateValidator.class),
                               any(CommandWithFileNameAndCommitMessage.class));
         verify(validationPopup,
                never()).showCopyValidationMessages(any(Command.class),
@@ -498,7 +534,7 @@ public class DataModelerScreenPresenterTest
 
         verify(copyPopUpPresenter,
                never()).show(any(Path.class),
-                             any(JavaFileNameValidator.class),
+                             any(JavaAssetUpdateValidator.class),
                              any(CommandWithFileNameAndCommitMessage.class));
         verify(validationPopup,
                times(1)).showCopyValidationMessages(any(Command.class),
@@ -506,6 +542,57 @@ public class DataModelerScreenPresenterTest
                                                     anyListOf(ValidationMessage.class));
     }
 
+    @Test
+    public void onCopyWithTargetPathTest() {
+        prepareOnCopyTest();
+        presenter.onCopy();
+        verify(copyPopUpPresenter,
+               times(1)).show(pathArgumentCaptor.capture(),
+                              validatorArgumentCaptor.capture(),
+                              commandWithFileNameArgumentCaptor.capture());
+
+        Path targetPath = mock(Path.class);
+        when(copyPopUpPresenterView.getTargetPath()).thenReturn(targetPath);
+        commandWithFileNameArgumentCaptor.getValue().execute(commitMessage);
+
+        verify(modelerService,
+               times(1)).copy(path,
+                              FILE_NAME,
+                              null,
+                              targetPath,
+                              COMMIT_MESSAGE,
+                              true);
+    }
+
+    @Test
+    public void onCopyWithNoTargetPathTest() {
+        prepareOnCopyTest();
+        presenter.onCopy();
+        verify(copyPopUpPresenter,
+               times(1)).show(pathArgumentCaptor.capture(),
+                              validatorArgumentCaptor.capture(),
+                              commandWithFileNameArgumentCaptor.capture());
+
+        when(copyPopUpPresenterView.getTargetPath()).thenReturn(null);
+        commandWithFileNameArgumentCaptor.getValue().execute(commitMessage);
+
+        verify(modelerService,
+               times(1)).copy(path,
+                              FILE_NAME,
+                              COMMIT_MESSAGE,
+                              true);
+    }
+
+    private void prepareOnCopyTest() {
+        when(validationService.validateForCopy(any(Path.class),
+                                               any(DataObject.class))).thenReturn(Collections.emptyList());
+        presenter.context = mock(DataModelerContext.class);
+
+        when(commitMessage.getCommitMessage()).thenReturn(COMMIT_MESSAGE);
+        when(commitMessage.getNewFileName()).thenReturn(FILE_NAME);
+        when(versionRecordManager.getCurrentPath()).thenReturn(path);
+    }
+
     @Test
     public void testMakeMenuBar() {
         doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
