@@ -30,6 +30,8 @@ import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 import javax.inject.Named;
 
+import org.ext.uberfire.social.activities.model.SocialUser;
+import org.ext.uberfire.social.activities.service.SocialUserRepositoryAPI;
 import org.guvnor.common.services.project.context.ProjectContextChangeEvent;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.POM;
@@ -78,7 +80,7 @@ import org.uberfire.paging.PageResponse;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.authz.AuthorizationManager;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 @Service
 @ApplicationScoped
@@ -100,6 +102,7 @@ public class LibraryServiceImpl implements LibraryService {
     private KieProjectService projectService;
     private ExamplesService examplesService;
     private IOService ioService;
+    private SocialUserRepositoryAPI socialUserRepositoryAPI;
 
     public LibraryServiceImpl() {
     }
@@ -116,7 +119,8 @@ public class LibraryServiceImpl implements LibraryService {
                               final KieProjectService projectService,
                               final ExamplesService examplesService,
                               @Named("ioStrategy") final IOService ioService,
-                              final LibraryInternalPreferences internalPreferences) {
+                              final LibraryInternalPreferences internalPreferences,
+                              final SocialUserRepositoryAPI socialUserRepositoryAPI) {
         this.ouService = ouService;
         this.repositoryService = repositoryService;
         this.kieProjectService = kieProjectService;
@@ -129,6 +133,7 @@ public class LibraryServiceImpl implements LibraryService {
         this.examplesService = examplesService;
         this.ioService = ioService;
         this.internalPreferences = internalPreferences;
+        this.socialUserRepositoryAPI = socialUserRepositoryAPI;
     }
 
     @Override
@@ -186,6 +191,33 @@ public class LibraryServiceImpl implements LibraryService {
         return kieProject;
     }
 
+    @Override
+    public KieProject createProject(final String name,
+                                    final String description,
+                                    final String groupId,
+                                    final String artifactId,
+                                    final String version,
+                                    final OrganizationalUnit selectedOrganizationalUnit,
+                                    final Repository selectedRepository,
+                                    final String baseURL,
+                                    final DeploymentMode mode) {
+        final Path selectedRepositoryRootPath = selectedRepository.getRoot();
+
+        final GAV gav = new GAV(groupId,
+                                artifactId,
+                                version);
+        final POM pom = createPOM(name,
+                                  description,
+                                  gav);
+
+        final KieProject kieProject = kieProjectService.newProject(selectedRepositoryRootPath,
+                                                                   pom,
+                                                                   baseURL,
+                                                                   mode);
+
+        return kieProject;
+    }
+
     @Override
     public Boolean thereIsAProjectInTheWorkbench() {
         return getOrganizationalUnits().stream()
@@ -220,7 +252,8 @@ public class LibraryServiceImpl implements LibraryService {
         final PageResponse<RefactoringPageRow> findRulesByProjectQuery = refactoringQueryService.query(new RefactoringPageRequest(FindAllLibraryAssetsQuery.NAME,
                                                                                                                                   queryTerms,
                                                                                                                                   query.getStartIndex(),
-                                                                                                                                  query.getAmount()));
+                                                                                                                                  query.getAmount(),
+                                                                                                                                  Boolean.TRUE));
         final List<FolderItem> assets = findRulesByProjectQuery
                 .getPageRowList()
                 .stream()
@@ -272,6 +305,12 @@ public class LibraryServiceImpl implements LibraryService {
     public Boolean hasAssets(final Project project) {
         checkNotNull("project",
                      project);
+
+        final boolean projectStillExists = ioService.exists(Paths.convert(project.getRootPath()));
+        if (!projectStillExists) {
+            return false;
+        }
+
         final Package defaultPackage = projectService.resolveDefaultPackage(project);
         return explorerServiceHelper.hasAssets(defaultPackage);
     }
@@ -286,6 +325,16 @@ public class LibraryServiceImpl implements LibraryService {
         return examplesService.getProjects(repository);
     }
 
+    @Override
+    public Set<ExampleProject> getProjects(final String repositoryUrl) {
+        if (repositoryUrl == null) {
+            return getExampleProjects();
+        }
+
+        final ExampleRepository repository = new ExampleRepository(repositoryUrl);
+        return examplesService.getProjects(repository);
+    }
+
     @Override
     public Project importProject(final ExampleProject exampleProject) {
         final OrganizationalUnit ou = getDefaultOrganizationalUnit();
@@ -327,6 +376,13 @@ public class LibraryServiceImpl implements LibraryService {
                        preferences.getProjectPreferences().getVersion());
     }
 
+    @Override
+    public List<SocialUser> getAllUsers() {
+        return socialUserRepositoryAPI.findAllUsers().stream()
+                .filter(user -> !user.getUserName().equals("system"))
+                .collect(Collectors.toList());
+    }
+
     String getCustomImportProjectsUrl() {
         return System.getProperty("org.kie.project.examples.repository.url");
     }
@@ -359,8 +415,22 @@ public class LibraryServiceImpl implements LibraryService {
 
     private List<Project> getProjects(final Repository repository,
                                       final String branch) {
-        return new ArrayList<>(kieProjectService.getProjects(repository,
-                                                             branch));
+        final List<Project> projects = new ArrayList<>(kieProjectService.getProjects(repository,
+                                                                                     branch));
+        projects.forEach(project -> project.setNumberOfAssets(getNumberOfAssets(project)));
+
+        return projects;
+    }
+
+    private int getNumberOfAssets(final Project project) {
+        final HashSet<ValueIndexTerm> queryTerms = new HashSet<>();
+        queryTerms.add(new LibraryValueProjectRootPathIndexTerm(project.getRootPath().toURI()));
+
+        return refactoringQueryService.queryHitCount(new RefactoringPageRequest(FindAllLibraryAssetsQuery.NAME,
+                                                                                queryTerms,
+                                                                                0,
+                                                                                null,
+                                                                                Boolean.TRUE));
     }
 
     private OrganizationalUnit getDefaultOrganizationalUnit() {
@@ -435,9 +505,15 @@ public class LibraryServiceImpl implements LibraryService {
         }
 
         final LibraryPreferences preferences = getPreferences();
+
+        final List<String> contributors = new ArrayList<>();
+        contributors.add(preferences.getOrganizationalUnitPreferences().getOwner());
+
         return ouService.createOrganizationalUnit(preferences.getOrganizationalUnitPreferences().getName(),
                                                   preferences.getOrganizationalUnitPreferences().getOwner(),
-                                                  preferences.getOrganizationalUnitPreferences().getGroupId());
+                                                  preferences.getOrganizationalUnitPreferences().getGroupId(),
+                                                  Collections.emptyList(),
+                                                  contributors);
     }
 
     private Repository createDefaultRepository(final OrganizationalUnit ou,
