@@ -16,6 +16,7 @@
 package org.kie.workbench.common.screens.server.management.client.wizard.container;
 
 import java.util.ArrayList;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
@@ -25,6 +26,7 @@ import com.google.gwt.event.dom.client.ChangeEvent;
 import com.google.gwt.event.dom.client.ChangeHandler;
 import com.google.gwt.user.client.DOM;
 import com.google.gwt.user.client.ui.Composite;
+import org.gwtbootstrap3.client.ui.CheckBox;
 import org.gwtbootstrap3.client.ui.TextBox;
 import org.gwtbootstrap3.client.ui.constants.ValidationState;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
@@ -36,7 +38,7 @@ import org.kie.workbench.common.screens.server.management.client.widget.Div;
 import org.kie.workbench.common.screens.server.management.client.widget.artifact.ArtifactListWidgetPresenter;
 import org.uberfire.ext.widgets.common.client.common.StyleHelper;
 
-import static org.uberfire.commons.validation.PortablePreconditions.*;
+import static org.kie.soup.commons.validation.PortablePreconditions.*;
 
 @Dependent
 @Templated
@@ -86,6 +88,10 @@ public class NewContainerFormView extends Composite
     @DataField("new-version")
     TextBox version;
 
+    @Inject
+    @DataField("new-start-container")
+    CheckBox startContainer;
+
     @Inject
     @DataField("content-area")
     Div content;
@@ -93,64 +99,65 @@ public class NewContainerFormView extends Composite
     private final ArrayList<ContentChangeHandler> changeHandlers = new ArrayList<ContentChangeHandler>();
 
     @Inject
-    public NewContainerFormView( final TranslationService translationService ) {
+    public NewContainerFormView(final TranslationService translationService) {
         super();
         this.translationService = translationService;
     }
 
     @Override
-    public void init( final NewContainerFormPresenter presenter ) {
-        containerName.addChangeHandler( new ChangeHandler() {
+    public void init(final NewContainerFormPresenter presenter) {
+        containerName.addChangeHandler(new ChangeHandler() {
             @Override
-            public void onChange( ChangeEvent event ) {
-                if ( presenter.isContainerNameValid() ) {
+            public void onChange(ChangeEvent event) {
+                if (presenter.isContainerNameValid()) {
                     noErrorOnContainerName();
                 } else {
                     errorOnContainerName();
                 }
                 fireChangeHandlers();
             }
-        } );
+        });
 
-        groupId.addChangeHandler( new ChangeHandler() {
+        groupId.addChangeHandler(new ChangeHandler() {
             @Override
-            public void onChange( ChangeEvent event ) {
-                if ( presenter.isGroupIdValid() ) {
+            public void onChange(ChangeEvent event) {
+                if (presenter.isGroupIdValid()) {
                     noErrorOnGroupId();
                 } else {
                     errorOnGroupId();
                 }
                 fireChangeHandlers();
             }
-        } );
+        });
 
-        artifactId.addChangeHandler( new ChangeHandler() {
+        artifactId.addChangeHandler(new ChangeHandler() {
             @Override
-            public void onChange( ChangeEvent event ) {
-                if ( presenter.isArtifactIdValid() ) {
+            public void onChange(ChangeEvent event) {
+                if (presenter.isArtifactIdValid()) {
                     noErrorOnArtifactId();
                 } else {
                     errorOnArtifactId();
                 }
                 fireChangeHandlers();
             }
-        } );
+        });
 
-        version.addChangeHandler( new ChangeHandler() {
+        version.addChangeHandler(new ChangeHandler() {
             @Override
-            public void onChange( ChangeEvent event ) {
-                if ( presenter.isVersionValid() ) {
+            public void onChange(ChangeEvent event) {
+                if (presenter.isVersionValid()) {
                     noErrorOnVersion();
                 } else {
                     errorOnVersion();
                 }
                 fireChangeHandlers();
             }
-        } );
+        });
+        startContainer.setText(getStartContainerCheckBoxText());
     }
 
     private void fireChangeHandlers() {
-        for ( final ContentChangeHandler changeHandler : changeHandlers ) {
+        for (final ContentChangeHandler changeHandler : changeHandlers) {
             changeHandler.onContentChange();
         }
     }
@@ -161,17 +168,18 @@ public class NewContainerFormView extends Composite
     }
 
     @Override
-    public void setArtifactListWidgetView( final ArtifactListWidgetPresenter.View view ) {
-        content.add( view );
+    public void setArtifactListWidgetView(final ArtifactListWidgetPresenter.View view) {
+        content.add(view);
     }
 
     @Override
     public void clear() {
-        containerName.setText( "" );
-        containerAlias.setText( "" );
-        groupId.setText( "" );
-        artifactId.setText( "" );
-        version.setText( "" );
+        containerName.setText("");
+        containerAlias.setText("");
+        groupId.setText("");
+        artifactId.setText("");
+        version.setText("");
+        startContainer.setValue(false);
 
         noErrors();
     }
@@ -186,48 +194,67 @@ public class NewContainerFormView extends Composite
 
     @Override
     public void noErrorOnContainerName() {
-        containerNameHelp.getStyle().setVisibility( Style.Visibility.HIDDEN );
-        StyleHelper.addUniqueEnumStyleName( containerNameGroup, ValidationState.class, ValidationState.NONE );
+        containerNameHelp.getStyle().setVisibility(Style.Visibility.HIDDEN);
+        StyleHelper.addUniqueEnumStyleName(containerNameGroup,
+                                           ValidationState.class,
+                                           ValidationState.NONE);
     }
 
     @Override
     public void noErrorOnGroupId() {
-        StyleHelper.addUniqueEnumStyleName( groupIdGroup, ValidationState.class, ValidationState.NONE );
+        StyleHelper.addUniqueEnumStyleName(groupIdGroup,
+                                           ValidationState.class,
+                                           ValidationState.NONE);
     }
 
     @Override
     public void noErrorOnArtifactId() {
-        StyleHelper.addUniqueEnumStyleName( artifactIdGroup, ValidationState.class, ValidationState.NONE );
+        StyleHelper.addUniqueEnumStyleName(artifactIdGroup,
+                                           ValidationState.class,
+                                           ValidationState.NONE);
     }
 
     @Override
     public void noErrorOnVersion() {
-        StyleHelper.addUniqueEnumStyleName( versionGroup, ValidationState.class, ValidationState.NONE );
+        StyleHelper.addUniqueEnumStyleName(versionGroup,
+                                           ValidationState.class,
+                                           ValidationState.NONE);
     }
 
     @Override
-    public void addContentChangeHandler( final ContentChangeHandler contentChangeHandler ) {
-        changeHandlers.add( checkNotNull( "contentChangeHandler", contentChangeHandler ) );
+    public void addContentChangeHandler(final ContentChangeHandler contentChangeHandler) {
+        changeHandlers.add(checkNotNull("contentChangeHandler",
+                                        contentChangeHandler));
     }
 
     @Override
-    public void setGroupId( final String value ) {
-        groupId.setText( value );
+    public void setGroupId(final String value) {
+        groupId.setText(value);
     }
 
     @Override
-    public void setArtifactId( final String value ) {
-        artifactId.setText( value );
+    public void setArtifactId(final String value) {
+        artifactId.setText(value);
     }
 
     @Override
-    public void setVersion( final String value ) {
-        version.setText( value );
+    public void setVersion(final String value) {
+        version.setText(value);
     }
 
     @Override
-    public void setContainerName( final String value ) {
-        containerName.setText( value );
+    public void setContainerName(final String value) {
+        containerName.setText(value);
+    }
+
+    @Override
+    public boolean isStartContainer() {
+        return startContainer.getValue();
+    }
+
+    @Override
+    public void setStartContainer(boolean startContainer) {
+        this.startContainer.setValue(startContainer);
     }
 
     @Override
@@ -257,52 +284,64 @@ public class NewContainerFormView extends Composite
 
     @Override
     public void errorOnContainerName() {
-        StyleHelper.addUniqueEnumStyleName( containerNameGroup, ValidationState.class, ValidationState.ERROR );
+        StyleHelper.addUniqueEnumStyleName(containerNameGroup,
+                                           ValidationState.class,
+                                           ValidationState.ERROR);
     }
 
     @Override
-    public void errorOnContainerName( final String message ) {
+    public void errorOnContainerName(final String message) {
         errorOnContainerName();
-        containerNameHelp.getStyle().setVisibility( Style.Visibility.VISIBLE );
-        containerNameHelp.setInnerText( message );
+        containerNameHelp.getStyle().setVisibility(Style.Visibility.VISIBLE);
+        containerNameHelp.setInnerText(message);
     }
 
     @Override
     public void errorOnGroupId() {
-        StyleHelper.addUniqueEnumStyleName( groupIdGroup, ValidationState.class, ValidationState.ERROR );
+        StyleHelper.addUniqueEnumStyleName(groupIdGroup,
+                                           ValidationState.class,
+                                           ValidationState.ERROR);
     }
 
     @Override
     public void errorOnArtifactId() {
-        StyleHelper.addUniqueEnumStyleName( artifactIdGroup, ValidationState.class, ValidationState.ERROR );
+        StyleHelper.addUniqueEnumStyleName(artifactIdGroup,
+                                           ValidationState.class,
+                                           ValidationState.ERROR);
     }
 
     @Override
     public void errorOnVersion() {
-        StyleHelper.addUniqueEnumStyleName( versionGroup, ValidationState.class, ValidationState.ERROR );
+        StyleHelper.addUniqueEnumStyleName(versionGroup,
+                                           ValidationState.class,
+                                           ValidationState.ERROR);
     }
 
     @Override
     public String getInvalidErrorMessage() {
-        return translationService.format( Constants.NewContainerFormView_InvalidErrorMessage );
+        return translationService.format(Constants.NewContainerFormView_InvalidErrorMessage);
     }
 
     @Override
     public String getNewContainerWizardTitle() {
-        return translationService.format( Constants.NewContainerFormView_NewContainerWizardTitle );
+        return translationService.format(Constants.NewContainerFormView_NewContainerWizardTitle);
     }
 
     @Override
     public String getNewContainerWizardSaveSuccess() {
-        return translationService.format( Constants.NewContainerFormView_NewContainerWizardSaveSuccess );
+        return translationService.format(Constants.NewContainerFormView_NewContainerWizardSaveSuccess);
     }
 
     @Override
     public String getNewContainerWizardSaveError() {
-        return translationService.format( Constants.NewContainerFormView_NewContainerWizardSaveError );
+        return translationService.format(Constants.NewContainerFormView_NewContainerWizardSaveError);
     }
 
     private String getTitleText() {
-        return translationService.format( Constants.NewContainerFormView_TitleText );
+        return translationService.format(Constants.NewContainerFormView_TitleText);
+    }
+
+    private String getStartContainerCheckBoxText() {
+        return translationService.format(Constants.NewContainerFormView_StartContainerText);
     }
 }
