@@ -71,7 +71,7 @@ public interface DefaultWorkbenchConstants
 
     String Process_Dashboard();
 
-    String Business_Dashboards();
+    String Content_Management();
 
     String Group();
 
@@ -160,4 +160,11 @@ public interface DefaultWorkbenchConstants
     String XLSScoreCard();
 
     String StunnerDesigner();
+
+    String InvalidBusResponseProbablySessionTimeout();
+
+    String SessionTimeout();
+
+    String LayoutEditorComponentPalette();
+
 }
