@@ -23,8 +23,8 @@ import java.util.Map.Entry;
 import java.util.Set;
 
 import org.drools.compiler.compiler.DrlExprParser;
-import org.drools.compiler.lang.descr.AccumulateDescr;
 import org.drools.compiler.lang.descr.AccumulateDescr.AccumulateFunctionCallDescr;
+import org.drools.compiler.lang.descr.AccumulateDescr;
 import org.drools.compiler.lang.descr.AccumulateImportDescr;
 import org.drools.compiler.lang.descr.ActionDescr;
 import org.drools.compiler.lang.descr.AndDescr;
@@ -79,18 +79,17 @@ import org.drools.compiler.lang.descr.UnitDescr;
 import org.drools.compiler.lang.descr.VariableRestrictionDescr;
 import org.drools.compiler.lang.descr.WindowDeclarationDescr;
 import org.drools.compiler.lang.descr.WindowReferenceDescr;
-import org.drools.workbench.models.datamodel.oracle.ModelField;
-import org.drools.workbench.models.datamodel.oracle.ModelField.FIELD_CLASS_TYPE;
-import org.drools.workbench.models.datamodel.oracle.ProjectDataModelOracle;
 import org.kie.internal.builder.conf.LanguageLevelOption;
-import org.kie.workbench.common.services.refactoring.backend.server.impact.ResourceReferenceCollector;
+import org.kie.soup.commons.validation.PortablePreconditions;
+import org.kie.soup.project.datamodel.oracle.ModelField;
+import org.kie.soup.project.datamodel.oracle.ProjectDataModelOracle;
 import org.kie.workbench.common.services.refactoring.ResourceReference;
 import org.kie.workbench.common.services.refactoring.SharedPart;
+import org.kie.workbench.common.services.refactoring.backend.server.impact.ResourceReferenceCollector;
 import org.kie.workbench.common.services.refactoring.service.PartType;
 import org.kie.workbench.common.services.refactoring.service.ResourceType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.uberfire.commons.validation.PortablePreconditions;
 import org.uberfire.ext.metadata.model.KProperty;
 
 public class PackageDescrIndexVisitor extends ResourceReferenceCollector {
@@ -748,7 +747,7 @@ public class PackageDescrIndexVisitor extends ResourceReferenceCollector {
             ModelField[] mfs = entry.getValue();
             String key = entry.getKey();
             for (ModelField mf : mfs) {
-                if (mf.getClassType().equals(FIELD_CLASS_TYPE.REGULAR_CLASS)) {
+                if (mf.getClassType().equals(ModelField.FIELD_CLASS_TYPE.REGULAR_CLASS)) {
                     if (mf.getClassName().endsWith("." + typeName)) {
                         return mf.getClassName();
                     } else if (mf.getType().endsWith("." + typeName)) {
