@@ -21,6 +21,7 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
@@ -31,7 +32,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.controls.AbstractCanv
 import org.kie.workbench.common.stunner.core.client.canvas.controls.resize.ResizeControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.AbstractCanvasHandlerEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
-import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasElementSelectedEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
@@ -47,7 +48,7 @@ import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewEventTy
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.impl.CommandResultImpl;
-import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapter;
 import org.kie.workbench.common.stunner.core.definition.property.PropertyMetaTypes;
@@ -62,7 +63,7 @@ import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.rule.violations.BoundsExceededViolation;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 @Dependent
 public class ResizeControlImpl extends AbstractCanvasHandlerRegistrationControl<AbstractCanvasHandler> implements ResizeControl<AbstractCanvasHandler, Element> {
@@ -146,14 +147,17 @@ public class ResizeControlImpl extends AbstractCanvasHandlerRegistrationControl<
     }
 
     @SuppressWarnings("unchecked")
-    private void onCanvasElementSelectedEvent(@Observes CanvasElementSelectedEvent event) {
+    private void onCanvasSelectionEvent(@Observes CanvasSelectionEvent event) {
         checkNotNull("event",
                      event);
-        final String uuid = event.getElementUUID();
-        if (isSameCanvas(event) && isRegistered(uuid)) {
-            final HasControlPoints<?> hasControlPoints = getControlPointsInstance(uuid);
-            if (!hasControlPoints.areControlsVisible()) {
-                showCPs(hasControlPoints);
+        if (event.getIdentifiers().size() == 1) {
+            final String uuid = event.getIdentifiers().iterator().next();
+            if (isSameCanvas(event) && isRegistered(uuid)) {
+                hideALLCPs();
+                final HasControlPoints<?> hasControlPoints = getControlPointsInstance(uuid);
+                if (!hasControlPoints.areControlsVisible()) {
+                    showCPs(hasControlPoints);
+                }
             }
         }
     }
@@ -254,7 +258,7 @@ public class ResizeControlImpl extends AbstractCanvasHandlerRegistrationControl<
             final CanvasViolation cv = CanvasViolationImpl.Builder.build(new BoundsExceededViolation(newBounds)
                                                                                  .setUUID(canvasHandler.getUuid()));
 
-            return new CommandResultImpl<CanvasViolation>(
+            return new CommandResultImpl<>(
                     CommandResult.Type.ERROR,
                     Collections.singleton(cv)
             );
@@ -263,16 +267,16 @@ public class ResizeControlImpl extends AbstractCanvasHandlerRegistrationControl<
         final List<Command<AbstractCanvasHandler, CanvasViolation>> commands = getResizeCommands(element,
                                                                                                  w,
                                                                                                  h);
-        final CompositeCommandImpl.CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation> commandBuilder =
-                new CompositeCommandImpl.CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation>();
+        final CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation> commandBuilder =
+                new CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation>();
         if (null != commands) {
             if (null != x && null != y) {
                 commandBuilder
                         .addCommand(canvasCommandFactory.updatePosition((Node<View<?>, Edge>) element,
-                                                                        x,
-                                                                        y));
+                                                                        new Point2D(x,
+                                                                                    y)));
             }
-            commands.stream().forEach(commandBuilder::addCommand);
+            commands.forEach(commandBuilder::addCommand);
         }
         final CommandResult<CanvasViolation> resizeResults = getCommandManager().execute(canvasHandler,
                                                                                          commandBuilder.build());
@@ -291,7 +295,7 @@ public class ResizeControlImpl extends AbstractCanvasHandlerRegistrationControl<
     private List<Command<AbstractCanvasHandler, CanvasViolation>> getResizeCommands(final Element<? extends Definition<?>> element,
                                                                                     final double w,
                                                                                     final double h) {
-        final Definition content = (Definition) element.getContent();
+        final Definition content = element.getContent();
         final Object def = content.getDefinition();
         final DefinitionAdapter<Object> adapter =
                 canvasHandler.getDefinitionManager()
