@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.client.lienzo.canvas.wires;
 import java.util.Optional;
 
 import com.ait.lienzo.client.core.shape.wires.WiresManager;
+import com.ait.lienzo.client.core.shape.wires.handlers.WiresControlFactory;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.user.client.ui.IsWidget;
 import org.junit.Before;
@@ -35,8 +36,12 @@ import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.mockito.Mock;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.anyInt;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class WiresCanvasTest {
@@ -112,6 +117,11 @@ public class WiresCanvasTest {
                 //Not tested
             }
 
+            @Override
+            protected WiresControlFactory getWiresControlFactory() {
+                return null;
+            }
+
             @Override
             public Canvas initialize(final int width,
                                      final int height) {
