@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.shape.animation;
 
+import java.util.Collections;
+
 import com.ait.lienzo.client.core.animation.AnimationCallback;
 import com.ait.lienzo.client.core.animation.AnimationProperties;
 import com.ait.lienzo.client.core.animation.AnimationTweener;
@@ -23,17 +25,17 @@ import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.lienzo.shape.view.LienzoShapeView;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
-import org.kie.workbench.common.stunner.core.client.shape.ShapeViewExtStub;
-import org.kie.workbench.common.stunner.core.client.shape.view.HasDecorators;
-import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyDouble;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class ShapeDecoratorAnimationTest {
@@ -45,6 +47,9 @@ public class ShapeDecoratorAnimationTest {
     @Mock
     private Shape<?> shape;
 
+    @Mock
+    private LienzoShapeView<?> shapeView;
+
     @Mock
     private com.ait.lienzo.client.core.shape.Shape<?> decorator;
 
@@ -53,9 +58,8 @@ public class ShapeDecoratorAnimationTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        final ShapeView shapeView = new ShapeViewExtStub();
-        ((HasDecorators) shapeView).getDecorators().add(decorator);
         when(shape.getShapeView()).thenReturn(shapeView);
+        when(shapeView.getDecorators()).thenReturn(Collections.singletonList(decorator));
         this.tested = new ShapeDecoratorAnimation(COLOR,
                                                   STROKE_WIDTH,
                                                   STROKE_ALPHA);
