@@ -17,6 +17,7 @@
 package org.kie.workbench.common.stunner.client.widgets.palette;
 
 import java.util.List;
+
 import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
 import javax.enterprise.context.Dependent;
@@ -26,22 +27,23 @@ import javax.inject.Inject;
 import org.jboss.errai.common.client.api.IsElement;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.stunner.client.widgets.palette.categories.DefinitionPaletteCategoryWidget;
 import org.kie.workbench.common.stunner.client.widgets.palette.factory.BS3PaletteViewFactory;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasFocusedEvent;
-import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasElementSelectedEvent;
 import org.kie.workbench.common.stunner.core.client.components.glyph.ShapeGlyphDragHandler;
 import org.kie.workbench.common.stunner.core.client.components.palette.AbstractPalette;
 import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionPaletteCategory;
 import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionSetPalette;
+import org.kie.workbench.common.stunner.core.client.event.screen.ScreenMaximizedEvent;
+import org.kie.workbench.common.stunner.core.client.event.screen.ScreenMinimizedEvent;
 import org.kie.workbench.common.stunner.core.client.service.ClientFactoryService;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
-import org.uberfire.commons.validation.PortablePreconditions;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 @Dependent
 public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
@@ -151,6 +153,21 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
         }
     }
 
+    @Override
+    public void setVisible(final PaletteVisibility visibility) {
+        view.showEmptyView(!visibility.isVisible());
+    }
+
+    @Override
+    public void onScreenMaximized(final ScreenMaximizedEvent event) {
+        setVisible(event.isDiagramScreen() ? PaletteWidget.VISIBLE : PaletteWidget.HIDDEN);
+    }
+
+    @Override
+    public void onScreenMinimized(final ScreenMinimizedEvent event) {
+        setVisible(PaletteWidget.VISIBLE);
+    }
+
     protected ShapeFactory getShapeFactory() {
         final DefinitionSetPalette palette = paletteDefinition;
         return shapeManager.getDefaultShapeSet(palette.getDefinitionSetId()).getShapeFactory();
@@ -267,11 +284,6 @@ public class BS3PaletteWidgetImpl extends AbstractPalette<DefinitionSetPalette>
                      canvasFocusedEvent);
     }
 
-    void onCanvasElementSelectedEvent(final @Observes CanvasElementSelectedEvent canvasElementSelectedEvent) {
-        checkNotNull("canvasElementSelectedEvent",
-                     canvasElementSelectedEvent);
-    }
-
     @PreDestroy
     @Override
     protected void doDestroy() {
