@@ -19,6 +19,8 @@ package org.kie.workbench.common.stunner.client.widgets.presenters.session;
 import java.util.function.Predicate;
 
 import com.google.gwt.user.client.ui.IsWidget;
+import com.google.gwt.user.client.ui.ProvidesResize;
+import com.google.gwt.user.client.ui.RequiresResize;
 import org.kie.workbench.common.stunner.client.widgets.notification.Notification;
 import org.kie.workbench.common.stunner.client.widgets.palette.PaletteWidget;
 import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
@@ -26,13 +28,12 @@ import org.kie.workbench.common.stunner.client.widgets.presenters.diagram.Diagra
 import org.kie.workbench.common.stunner.client.widgets.toolbar.Toolbar;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.components.palette.model.PaletteDefinition;
-import org.kie.workbench.common.stunner.core.client.components.palette.model.definition.DefinitionSetPalette;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 
 /**
  * A session's presenter type for generic client session instances.
- * <p>
+ * <p/>
  * A session presenter is a client side component that has same goals as a SessionViewer/Editor, so displaying a diagram
  * and handling the different controls for either viewing or authoring purposes, but it provides some additional
  * features:
@@ -59,13 +60,25 @@ public interface SessionPresenter<S extends ClientSession, H extends CanvasHandl
         void afterSessionOpened();
     }
 
-    interface View extends IsWidget {
+    interface View extends IsWidget,
+                           RequiresResize,
+                           ProvidesResize {
+
+        IsWidget getCanvasWidget();
+
+        IsWidget getToolbarWidget();
+
+        IsWidget getPaletteWidget();
+
+        ScrollType getContentScrollType();
 
         View setCanvasWidget(final IsWidget widget);
 
         View setToolbarWidget(final IsWidget widget);
 
-        View setPaletteWidget(final IsWidget widget);
+        View setPaletteWidget(final PaletteWidget<PaletteDefinition> paletteWidget);
+
+        void setContentScrollType(final ScrollType handler);
 
         View showLoading(final boolean loading);
 
@@ -76,6 +89,11 @@ public interface SessionPresenter<S extends ClientSession, H extends CanvasHandl
         View showError(final String message);
 
         void destroy();
+
+        enum ScrollType {
+            AUTO,
+            CUSTOM
+        }
     }
 
     SessionPresenter<S, H, D> withToolbar(final boolean hasToolbar);
