@@ -20,6 +20,10 @@ import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
+import com.google.gwt.dom.client.Style;
+import com.google.gwt.event.dom.client.ContextMenuEvent;
+import com.google.gwt.event.dom.client.ScrollEvent;
+import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.IsWidget;
 import com.google.gwt.user.client.ui.Label;
@@ -29,9 +33,15 @@ import org.gwtbootstrap3.client.ui.gwt.FlowPanel;
 import org.gwtbootstrap3.extras.notify.client.constants.NotifyType;
 import org.gwtbootstrap3.extras.notify.client.ui.Notify;
 import org.gwtbootstrap3.extras.notify.client.ui.NotifySettings;
+import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.jboss.errai.ui.shared.api.annotations.DataField;
+import org.jboss.errai.ui.shared.api.annotations.EventHandler;
+import org.jboss.errai.ui.shared.api.annotations.ForEvent;
 import org.jboss.errai.ui.shared.api.annotations.Templated;
+import org.kie.workbench.common.stunner.client.widgets.palette.PaletteWidget;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
+import org.kie.workbench.common.stunner.core.client.components.palette.model.PaletteDefinition;
+import org.uberfire.client.workbench.widgets.listbar.ResizeFlowPanel;
 
 // TODO: i18n.
 @Dependent
@@ -52,14 +62,24 @@ public class SessionPresenterView extends Composite
 
     @Inject
     @DataField
-    private FlowPanel canvasPanel;
+    private ResizeFlowPanel canvasPanel;
 
     @Inject
     @DataField
     private FlowPanel palettePanel;
 
+    @Inject
+    @DataField
+    private SessionContainer sessionContainer;
+
     private final NotifySettings settings = NotifySettings.newSettings();
 
+    private ScrollType scrollType = ScrollType.AUTO;
+
+    private double paletteInitialTop;
+
+    private double paletteInitialLeft;
+
     @PostConstruct
     public void init() {
         settings.setShowProgressbar(false);
@@ -67,7 +87,45 @@ public class SessionPresenterView extends Composite
         settings.setAllowDismiss(true);
         settings.setDelay(DELAY);
         settings.setTimer(TIMER);
+        addDomHandler((e) -> {
+                          e.preventDefault();
+                          e.stopPropagation();
+                      },
+                      ContextMenuEvent.getType());
         showLoading(false);
+
+        //getting initial palette position
+        paletteInitialTop = palettePanel.getAbsoluteTop();
+        paletteInitialLeft = palettePanel.getAbsoluteLeft();
+    }
+
+    @EventHandler("sessionContainer")
+    protected void onScroll(@ForEvent("scroll") ScrollEvent e) {
+        // on the editor scroll recalculate palette position to be fixed on the screen
+        palettePanel.getElement().getStyle().setTop(paletteInitialTop + e.getRelativeElement().getScrollTop(), Style.Unit.PX);
+        palettePanel.getElement().getStyle().setLeft(paletteInitialLeft + e.getRelativeElement().getScrollLeft(), Style.Unit.PX);
+
+        e.preventDefault();
+    }
+
+    @Override
+    public IsWidget getCanvasWidget() {
+        return canvasPanel.getWidget(0);
+    }
+
+    @Override
+    public IsWidget getToolbarWidget() {
+        return toolbarPanel.getWidget(0);
+    }
+
+    @Override
+    public IsWidget getPaletteWidget() {
+        return palettePanel.getWidget(0);
+    }
+
+    @Override
+    public ScrollType getContentScrollType() {
+        return scrollType;
     }
 
     @Override
@@ -78,48 +136,12 @@ public class SessionPresenterView extends Composite
     }
 
     @Override
-    public SessionPresenterView setPaletteWidget(final IsWidget widget) {
+    public SessionPresenterView setPaletteWidget(final PaletteWidget<PaletteDefinition> paletteWidget) {
         setWidgetForPanel(palettePanel,
-                          widget);
+                          ElementWrapperWidget.getWidget(paletteWidget.getElement()));
         return this;
     }
 
-    @Override
-    public SessionPresenterView showError(final String message) {
-        settings.setType(NotifyType.DANGER);
-        showNotification("Error",
-                         message,
-                         IconType.CLOSE);
-        return this;
-    }
-
-    @Override
-    public SessionPresenter.View showWarning(final String message) {
-        settings.setType(NotifyType.WARNING);
-        showNotification("Warning",
-                         message,
-                         IconType.CLOSE);
-        return this;
-    }
-
-    @Override
-    public SessionPresenterView showMessage(final String message) {
-        settings.setType(NotifyType.SUCCESS);
-        showNotification("Info",
-                         message,
-                         IconType.STICKY_NOTE);
-        return this;
-    }
-
-    private void showNotification(final String title,
-                                  final String message,
-                                  final IconType icon) {
-        Notify.notify(title,
-                      message,
-                      icon,
-                      settings);
-    }
-
     @Override
     public SessionPresenterView setCanvasWidget(final IsWidget widget) {
         setWidgetForPanel(canvasPanel,
@@ -127,12 +149,65 @@ public class SessionPresenterView extends Composite
         return this;
     }
 
+    @Override
+    public void setContentScrollType(final ScrollType type) {
+        final Style style = sessionContainer.getElement().getStyle();
+        switch (type) {
+            case AUTO:
+                style.setOverflow(Style.Overflow.AUTO);
+                break;
+            case CUSTOM:
+                style.setOverflow(Style.Overflow.HIDDEN);
+        }
+    }
+
+    @Override
+    public SessionPresenterView showError(final String message) {
+        settings.setType(NotifyType.DANGER);
+        showNotification("Error",
+                         buildHtmlEscapedText(message),
+                         IconType.CLOSE);
+        return this;
+    }
+
+    @Override
+    public SessionPresenter.View showWarning(final String message) {
+        settings.setType(NotifyType.WARNING);
+        showNotification("Warning",
+                         buildHtmlEscapedText(message),
+                         IconType.CLOSE);
+        return this;
+    }
+
+    @Override
+    public SessionPresenterView showMessage(final String message) {
+        settings.setType(NotifyType.SUCCESS);
+        showNotification("Info",
+                         buildHtmlEscapedText(message),
+                         IconType.STICKY_NOTE);
+        return this;
+    }
+
+    private void showNotification(final String title,
+                                  final String message,
+                                  final IconType icon) {
+        Notify.notify(title,
+                      buildHtmlEscapedText(message),
+                      icon,
+                      settings);
+    }
+
     @Override
     public SessionPresenterView showLoading(final boolean loading) {
         loadingPanel.setVisible(loading);
         return this;
     }
 
+    @Override
+    public void onResize() {
+        canvasPanel.onResize();
+    }
+
     protected void setWidgetForPanel(final Panel panel,
                                      final IsWidget widget) {
         panel.clear();
@@ -142,4 +217,8 @@ public class SessionPresenterView extends Composite
     public void destroy() {
         this.removeFromParent();
     }
-}
+
+    private String buildHtmlEscapedText(final String message) {
+        return new SafeHtmlBuilder().appendEscapedLines(message).toSafeHtml().asString();
+    }
+}
\ No newline at end of file
