@@ -17,9 +17,11 @@
 package org.kie.workbench.common.stunner.client.widgets.presenters.session.impl;
 
 import java.lang.annotation.Annotation;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Observes;
 import javax.enterprise.inject.Any;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import org.jboss.errai.ioc.client.api.ManagedInstance;
@@ -37,6 +39,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.CanvasFactory;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SingleSelection;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.command.CanvasCommandExecutedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.command.CanvasUndoCommandExecutedEvent;
@@ -48,7 +51,7 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 /**
  * A generic session's preview instance for subtypes of <code>AbstractClientSession</code>.
@@ -57,6 +60,7 @@ import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull
  * size for the preview.
  */
 @Dependent
+@Default
 public class SessionPreviewImpl
         extends AbstractSessionViewer<AbstractClientSession, AbstractCanvasHandler>
         implements SessionDiagramPreview<AbstractClientSession> {
@@ -89,11 +93,11 @@ public class SessionPreviewImpl
                               final GraphUtils graphUtils,
                               final @Any ManagedInstance<BaseCanvasHandler> canvasHandlerFactories,
                               final @Any ManagedInstance<CanvasCommandFactory> canvasCommandFactories,
-                              final SelectionControl<AbstractCanvasHandler, ?> selectionControl,
+                              final @SingleSelection SelectionControl<AbstractCanvasHandler, ?> selectionControl,
                               final WidgetWrapperView view) {
         this.definitionManager = definitionManager;
         this.shapeManager = shapeManager;
-        this.textPropertyProviderFactory=textPropertyProviderFactory;
+        this.textPropertyProviderFactory = textPropertyProviderFactory;
         this.canvasCommandManager = canvasCommandManager;
 
         this.definitionUtils = definitionUtils;
@@ -215,11 +219,19 @@ public class SessionPreviewImpl
     }
 
     void commandExecutedFired(@Observes CanvasCommandExecutedEvent commandExecutedEvent) {
-        super.onCommandExecuted(commandExecutedEvent);
+        handleCanvasCommandExecutedEvent(commandExecutedEvent);
     }
 
     void commandUndoExecutedFired(@Observes CanvasUndoCommandExecutedEvent commandUndoExecutedEvent) {
-        super.onCommandUndoExecuted(commandUndoExecutedEvent);
+        handleCanvasUndoCommandExecutedEvent(commandUndoExecutedEvent);
+    }
+
+    protected void handleCanvasCommandExecutedEvent(final CanvasCommandExecutedEvent event) {
+        super.onCommandExecuted(event);
+    }
+
+    protected void handleCanvasUndoCommandExecutedEvent(final CanvasUndoCommandExecutedEvent event) {
+        super.onCommandUndoExecuted(event);
     }
 
     @Override
