@@ -20,16 +20,18 @@ import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import org.gwtbootstrap3.client.ui.constants.IconType;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.DeleteSelectionSessionCommand;
 import org.kie.workbench.common.stunner.core.client.session.command.impl.SessionCommandFactory;
+import org.kie.workbench.common.stunner.core.i18n.CoreTranslationMessages;
 
 @Dependent
 public class DeleteSelectionToolbarCommand extends AbstractToolbarCommand<ClientFullSession, DeleteSelectionSessionCommand> {
 
     @Inject
-    public DeleteSelectionToolbarCommand(final SessionCommandFactory sessionCommandFactory) {
-        super(sessionCommandFactory.newDeleteSelectedElementsCommand());
+    public DeleteSelectionToolbarCommand(final SessionCommandFactory sessionCommandFactory, final ClientTranslationService translationService) {
+        super(sessionCommandFactory.newDeleteSelectedElementsCommand(), translationService);
     }
 
     @Override
@@ -39,17 +41,16 @@ public class DeleteSelectionToolbarCommand extends AbstractToolbarCommand<Client
 
     @Override
     public String getCaption() {
-        return null;
+        return translationService.getKeyValue(CoreTranslationMessages.DELETE_SELECTION);
     }
 
-    // TODO: I18n.
     @Override
     public String getTooltip() {
-        return "Delete the selected elements";
+        return translationService.getKeyValue(CoreTranslationMessages.DELETE_SELECTION);
     }
 
     @Override
     protected boolean requiresConfirm() {
-        return true;
+        return false;
     }
 }
