@@ -20,12 +20,14 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarView;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ClearStatesToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ClearToolbarCommand;
+import org.kie.workbench.common.stunner.client.widgets.toolbar.command.CopyToolbarCommand;
+import org.kie.workbench.common.stunner.client.widgets.toolbar.command.CutToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.DeleteSelectionToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ExportToJpgToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ExportToPdfToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ExportToPngToolbarCommand;
+import org.kie.workbench.common.stunner.client.widgets.toolbar.command.PasteToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.RedoToolbarCommand;
-import org.kie.workbench.common.stunner.client.widgets.toolbar.command.RefreshToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.SwitchGridToolbarCommand;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.ToolbarCommandFactory;
 import org.kie.workbench.common.stunner.client.widgets.toolbar.command.UndoToolbarCommand;
@@ -58,10 +60,12 @@ public class EditorToolbar extends AbstractToolbar<AbstractClientFullSession> {
         addCommand(commandFactory.newUndoCommand());
         addCommand(commandFactory.newRedoCommand());
         addCommand(commandFactory.newValidateCommand());
-        addCommand(commandFactory.newRefreshCommand());
         addCommand(commandFactory.newExportToPngToolbarCommand());
         addCommand(commandFactory.newExportToJpgToolbarCommand());
         addCommand(commandFactory.newExportToPdfToolbarCommand());
+        addCommand(commandFactory.newCopyCommand());
+        addCommand(commandFactory.newCutToolbarCommand());
+        addCommand(commandFactory.newPasteCommand());
     }
 
     @Override
@@ -101,19 +105,28 @@ public class EditorToolbar extends AbstractToolbar<AbstractClientFullSession> {
         return (ValidateToolbarCommand) getCommand(7);
     }
 
-    public RefreshToolbarCommand getRefreshToolbarCommand() {
-        return (RefreshToolbarCommand) getCommand(8);
-    }
 
     public ExportToPngToolbarCommand getExportToPngToolbarCommand() {
-        return (ExportToPngToolbarCommand) getCommand(9);
+        return (ExportToPngToolbarCommand) getCommand(8);
     }
 
     public ExportToJpgToolbarCommand getExportToJpgToolbarCommand() {
-        return (ExportToJpgToolbarCommand) getCommand(10);
+        return (ExportToJpgToolbarCommand) getCommand(9);
     }
 
     public ExportToPdfToolbarCommand getExportToPdfToolbarCommand() {
-        return (ExportToPdfToolbarCommand) getCommand(11);
+        return (ExportToPdfToolbarCommand) getCommand(10);
+    }
+
+    public CopyToolbarCommand getCopyToolbarCommand() {
+        return (CopyToolbarCommand) getCommand(11);
+    }
+
+    public CutToolbarCommand getCutToolbarCommand() {
+        return (CutToolbarCommand) getCommand(12);
+    }
+
+    public PasteToolbarCommand getPasteToolbarCommand() {
+        return (PasteToolbarCommand) getCommand(13);
     }
 }
