@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,11 +25,6 @@ public interface ShapeSet<F extends ShapeFactory> {
      */
     String getId();
 
-    /**
-     * Get the name for the set.
-     */
-    String getName();
-
     /**
      * Get the description for the set.
      */
@@ -40,14 +35,9 @@ public interface ShapeSet<F extends ShapeFactory> {
      */
     String getDefinitionSetId();
 
-    /**
-     * If multiple shape sets available for same definition set,
-     * this indicates wheter is this shape set must be the default one.
-     */
-    boolean isDefault();
-
     /**
      * The shapes factory instance for this set.
      */
     F getShapeFactory();
+
 }
