@@ -16,6 +16,9 @@
 
 package org.kie.workbench.common.stunner.core.client.command;
 
+import java.util.Collection;
+import java.util.function.Consumer;
+
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.definition.morph.MorphDefinition;
 import org.kie.workbench.common.stunner.core.graph.Edge;
@@ -23,7 +26,9 @@ import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
+import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 
 public interface CanvasCommandFactory<H extends CanvasHandler> {
 
@@ -40,6 +45,8 @@ public interface CanvasCommandFactory<H extends CanvasHandler> {
 
     CanvasCommand<H> deleteNode(final Node candidate);
 
+    CanvasCommand<H> delete(final Collection<Element> candidates);
+
     CanvasCommand<H> addConnector(final Node sourceNode,
                                   final Edge candidate,
                                   final Connection connection,
@@ -73,20 +80,23 @@ public interface CanvasCommandFactory<H extends CanvasHandler> {
                                final String shapeSetId);
 
     CanvasCommand<H> setSourceNode(final Node<? extends View<?>, Edge> node,
-                                   final Edge<? extends View<?>, Node> edge,
+                                   final Edge<? extends ViewConnector<?>, Node> edge,
                                    final Connection connection);
 
     CanvasCommand<H> setTargetNode(final Node<? extends View<?>, Edge> node,
-                                   final Edge<? extends View<?>, Node> edge,
+                                   final Edge<? extends ViewConnector<?>, Node> edge,
                                    final Connection connection);
 
     CanvasCommand<H> updatePosition(final Node<View<?>, Edge> element,
-                                    final Double x,
-                                    final Double y);
+                                    final Point2D location);
 
     CanvasCommand<H> updatePropertyValue(final Element element,
                                          final String propertyId,
                                          final Object value);
 
     CanvasCommand<H> clearCanvas();
+
+    CanvasCommand<H> cloneNode(Node candidate, String parentUuid, Point2D cloneLocation, Consumer<Node> callback);
+
+    CanvasCommand<H> cloneConnector(Edge candidate, String sourceUUID, String targetUUID, String shapeSetId, Consumer<Edge> callback);
 }
