@@ -19,12 +19,15 @@ package org.kie.workbench.common.stunner.core.client.session;
 import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.command.Command;
+import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
 
 /**
@@ -34,7 +37,7 @@ import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
  * @param <C> The canvas.
  * @param <H> The canvas handler.
  */
-public interface ClientFullSession<C extends Canvas, H extends CanvasHandler>
+public interface ClientFullSession<C extends Canvas, H extends CanvasHandler, S extends ClientSession>
         extends ClientReadOnlySession<C, H> {
 
     CanvasCommandManager<H> getCommandManager();
@@ -48,4 +51,8 @@ public interface ClientFullSession<C extends Canvas, H extends CanvasHandler>
     DockingAcceptorControl<H> getDockingAcceptorControl();
 
     ElementBuilderControl<H> getBuilderControl();
+
+    KeyboardControl<C, S> getKeyboardControl();
+
+    ClipboardControl<Element, C, S> getClipboardControl();
 }
