@@ -16,6 +16,9 @@
 
 package org.kie.workbench.common.stunner.core.client.canvas.command;
 
+import java.util.Collection;
+import java.util.function.Consumer;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
@@ -29,7 +32,9 @@ import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
+import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
 import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.ChildrenTraverseProcessor;
 import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.ViewTraverseProcessor;
 
@@ -81,6 +86,11 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
         return new DeleteNodeCommand(candidate);
     }
 
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> delete(final Collection<Element> candidates) {
+        return new DeleteElementsCommand(candidates);
+    }
+
     @Override
     public CanvasCommand<AbstractCanvasHandler> addConnector(final Node sourceNode,
                                                              final Edge candidate,
@@ -158,7 +168,7 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
 
     @Override
     public CanvasCommand<AbstractCanvasHandler> setSourceNode(final Node<? extends View<?>, Edge> node,
-                                                              final Edge<? extends View<?>, Node> edge,
+                                                              final Edge<? extends ViewConnector<?>, Node> edge,
                                                               final Connection connection) {
         return new SetConnectionSourceNodeCommand(node,
                                                   edge,
@@ -167,7 +177,7 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
 
     @Override
     public CanvasCommand<AbstractCanvasHandler> setTargetNode(final Node<? extends View<?>, Edge> node,
-                                                              final Edge<? extends View<?>, Node> edge,
+                                                              final Edge<? extends ViewConnector<?>, Node> edge,
                                                               final Connection connection) {
         return new SetConnectionTargetNodeCommand(node,
                                                   edge,
@@ -176,11 +186,9 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
 
     @Override
     public CanvasCommand<AbstractCanvasHandler> updatePosition(final Node<View<?>, Edge> element,
-                                                               final Double x,
-                                                               final Double y) {
+                                                               final Point2D location) {
         return new UpdateElementPositionCommand(element,
-                                                x,
-                                                y);
+                                                location);
     }
 
     @Override
@@ -197,6 +205,16 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
         return new ClearCommand();
     }
 
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> cloneNode(Node candidate, String parentUuid, Point2D cloneLocation, Consumer<Node> cloneNodeCallback) {
+        return new CloneNodeCommand(candidate, parentUuid, cloneLocation, cloneNodeCallback, childrenTraverseProcessors);
+    }
+
+    @Override
+    public CanvasCommand<AbstractCanvasHandler> cloneConnector(Edge candidate, String sourceUUID, String targetUUID, String shapeSetId, Consumer<Edge> callback) {
+        return new CloneConnectorCommand(candidate, sourceUUID, targetUUID, shapeSetId, callback);
+    }
+
     protected ChildrenTraverseProcessor newChildrenTraverseProcessor() {
         return childrenTraverseProcessors.get();
     }
@@ -204,4 +222,8 @@ public class DefaultCanvasCommandFactory implements CanvasCommandFactory<Abstrac
     protected ViewTraverseProcessor newViewTraverseProcessor() {
         return viewTraverseProcessors.get();
     }
+
+    protected ManagedInstance<ChildrenTraverseProcessor> getChildrenTraverseProcessors() {
+        return childrenTraverseProcessors;
+    }
 }
