@@ -19,9 +19,11 @@ package org.kie.workbench.common.stunner.core.client.session.impl;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.pan.PanControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
@@ -29,12 +31,13 @@ import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.RequiresCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
 
 public abstract class AbstractClientFullSession extends AbstractClientReadOnlySession
-        implements ClientFullSession<AbstractCanvas, AbstractCanvasHandler> {
+        implements ClientFullSession<AbstractCanvas, AbstractCanvasHandler, ClientSession> {
 
     private CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager;
     private CommandRegistry<Command<AbstractCanvasHandler, CanvasViolation>> commandRegistry;
@@ -42,6 +45,8 @@ public abstract class AbstractClientFullSession extends AbstractClientReadOnlySe
     private ContainmentAcceptorControl<AbstractCanvasHandler> containmentAcceptorControl;
     private DockingAcceptorControl<AbstractCanvasHandler> dockingAcceptorControl;
     private ElementBuilderControl<AbstractCanvasHandler> builderControl;
+    private KeyboardControl<AbstractCanvas, ClientSession> keyboardControl;
+    private ClipboardControl<Element, AbstractCanvas, ClientSession> clipboardControl;
 
     public AbstractClientFullSession(final AbstractCanvas canvas,
                                      final AbstractCanvasHandler canvasHandler,
@@ -55,7 +60,9 @@ public abstract class AbstractClientFullSession extends AbstractClientReadOnlySe
                                      final ConnectionAcceptorControl<AbstractCanvasHandler> connectionAcceptorControl,
                                      final ContainmentAcceptorControl<AbstractCanvasHandler> containmentAcceptorControl,
                                      final DockingAcceptorControl<AbstractCanvasHandler> dockingAcceptorControl,
-                                     final ElementBuilderControl<AbstractCanvasHandler> builderControl) {
+                                     final ElementBuilderControl<AbstractCanvasHandler> builderControl,
+                                     final KeyboardControl<AbstractCanvas, ClientSession> keyboardControl,
+                                     final ClipboardControl<Element, AbstractCanvas, ClientSession> clipboardControl) {
         super(canvas,
               canvasHandler,
               selectionControl,
@@ -67,6 +74,8 @@ public abstract class AbstractClientFullSession extends AbstractClientReadOnlySe
         this.containmentAcceptorControl = containmentAcceptorControl;
         this.dockingAcceptorControl = dockingAcceptorControl;
         this.builderControl = builderControl;
+        this.keyboardControl = keyboardControl;
+        this.clipboardControl = clipboardControl;
         getRegistrationHandler().registerCanvasHandlerControl(connectionAcceptorControl);
         connectionAcceptorControl.setCommandManagerProvider(requestCommandManagerProvider);
         getRegistrationHandler().registerCanvasHandlerControl(containmentAcceptorControl);
@@ -75,6 +84,22 @@ public abstract class AbstractClientFullSession extends AbstractClientReadOnlySe
         dockingAcceptorControl.setCommandManagerProvider(requestCommandManagerProvider);
         getRegistrationHandler().registerCanvasHandlerControl(builderControl);
         builderControl.setCommandManagerProvider(sessionCommandManagerProvider);
+        getRegistrationHandler().registerCanvasControl(keyboardControl);
+    }
+
+    @Override
+    protected void doOpen() {
+        super.doOpen();
+        getRegistrationHandler().bind(this);
+    }
+
+    @Override
+    public void doDestroy() {
+        super.doDestroy();
+        getRegistrationHandler().unbind();
+        if (null != commandRegistry) {
+            commandRegistry.clear();
+        }
     }
 
     @Override
@@ -123,10 +148,12 @@ public abstract class AbstractClientFullSession extends AbstractClientReadOnlySe
     }
 
     @Override
-    public void doDestroy() {
-        super.doDestroy();
-        if (null != commandRegistry) {
-            commandRegistry.clear();
-        }
+    public KeyboardControl<AbstractCanvas, ClientSession> getKeyboardControl() {
+        return keyboardControl;
+    }
+
+    @Override
+    public ClipboardControl<Element, AbstractCanvas, ClientSession> getClipboardControl() {
+        return clipboardControl;
     }
 }
