@@ -31,10 +31,14 @@ import org.kie.workbench.common.stunner.core.graph.content.relationship.Dock;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertNotEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class SetCanvasChildNodeCommandTest extends AbstractCanvasCommandTest {
@@ -83,11 +87,11 @@ public class SetCanvasChildNodeCommandTest extends AbstractCanvasCommandTest {
                times(1)).addChild(eq(graph1Instance.startNode),
                                   eq(graph1Instance.intermNode));
         verify(canvasHandler,
-               times(1)).applyElementMutation(eq(graph1Instance.intermNode),
-                                              any(MutationContext.class));
+               never()).applyElementMutation(eq(graph1Instance.intermNode),
+                                             any(MutationContext.class));
         verify(canvasHandler,
-               times(1)).applyElementMutation(eq(graph1Instance.startNode),
-                                              any(MutationContext.class));
+               never()).applyElementMutation(eq(graph1Instance.startNode),
+                                             any(MutationContext.class));
         verify(canvasHandler,
                times(0)).dock(any(Node.class),
                               any(Node.class));
