@@ -22,13 +22,15 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasFactory;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.CanvasInPlaceTextEditorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.drag.DragControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.drag.LocationControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.pan.PanControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.resize.ResizeControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
@@ -39,55 +41,79 @@ import org.kie.workbench.common.stunner.core.client.canvas.listener.CanvasShapeL
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.RequiresCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.registry.RegistryFactory;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ClientFullSessionTest {
 
     @Mock
-    CanvasFactory<AbstractCanvas, AbstractCanvasHandler> factory;
+    private CanvasFactory<AbstractCanvas, AbstractCanvasHandler> factory;
+
     @Mock
-    AbstractCanvas canvas;
+    private AbstractCanvas canvas;
+
     @Mock
-    AbstractCanvasHandler canvasHandler;
+    private AbstractCanvasHandler canvasHandler;
+
     @Mock
-    SelectionControl<AbstractCanvasHandler, Element> selectionControl;
+    private SelectionControl<AbstractCanvasHandler, Element> selectionControl;
+
     @Mock
-    ZoomControl<AbstractCanvas> zoomControl;
+    private ZoomControl<AbstractCanvas> zoomControl;
+
     @Mock
-    PanControl<AbstractCanvas> panControl;
+    private PanControl<AbstractCanvas> panControl;
+
     @Mock
-    ResizeControl<AbstractCanvasHandler, Element> resizeControl;
+    private ResizeControl<AbstractCanvasHandler, Element> resizeControl;
+
     @Mock
-    CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager;
+    private CanvasCommandManager<AbstractCanvasHandler> canvasCommandManager;
+
     @Mock
-    SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
+    private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
+
     @Mock
-    SessionCommandManager<AbstractCanvasHandler> requestCommandManager;
+    private SessionCommandManager<AbstractCanvasHandler> requestCommandManager;
+
     @Mock
-    RegistryFactory registryFactory;
+    private RegistryFactory registryFactory;
+
     @Mock
-    ConnectionAcceptorControl<AbstractCanvasHandler> connectionAcceptorControl;
+    private ConnectionAcceptorControl<AbstractCanvasHandler> connectionAcceptorControl;
+
     @Mock
-    ContainmentAcceptorControl<AbstractCanvasHandler> containmentAcceptorControl;
+    private ContainmentAcceptorControl<AbstractCanvasHandler> containmentAcceptorControl;
+
     @Mock
-    DockingAcceptorControl<AbstractCanvasHandler> dockingAcceptorControl;
+    private DockingAcceptorControl<AbstractCanvasHandler> dockingAcceptorControl;
+
     @Mock
-    CanvasInPlaceTextEditorControl<AbstractCanvasHandler, Element> canvasInPlaceTextEditorControl;
+    private CanvasInPlaceTextEditorControl<AbstractCanvasHandler, ClientSession, Element> canvasInPlaceTextEditorControl;
+
     @Mock
-    DragControl<AbstractCanvasHandler, Element> dragControl;
+    private LocationControl<AbstractCanvasHandler, Element> locationControl;
+
     @Mock
-    ToolboxControl<AbstractCanvasHandler, Element> toolboxControl;
+    private ToolboxControl<AbstractCanvasHandler, Element> toolboxControl;
+
     @Mock
-    ElementBuilderControl<AbstractCanvasHandler> builderControl;
+    private ElementBuilderControl<AbstractCanvasHandler> builderControl;
+
+    @Mock
+    private KeyboardControl<Canvas, ClientSession> keyboardControl;
 
     private ClientFullSessionImpl tested;
 
@@ -102,10 +128,11 @@ public class ClientFullSessionTest {
         when(factory.newControl(eq(ConnectionAcceptorControl.class))).thenReturn(connectionAcceptorControl);
         when(factory.newControl(eq(ContainmentAcceptorControl.class))).thenReturn(containmentAcceptorControl);
         when(factory.newControl(eq(DockingAcceptorControl.class))).thenReturn(dockingAcceptorControl);
-        when(factory.newControl(eq(DragControl.class))).thenReturn(dragControl);
+        when(factory.newControl(eq(LocationControl.class))).thenReturn(locationControl);
         when(factory.newControl(eq(CanvasInPlaceTextEditorControl.class))).thenReturn(canvasInPlaceTextEditorControl);
         when(factory.newControl(eq(ToolboxControl.class))).thenReturn(toolboxControl);
         when(factory.newControl(eq(ElementBuilderControl.class))).thenReturn(builderControl);
+        when(factory.newControl(eq(KeyboardControl.class))).thenReturn(keyboardControl);
         when(canvasHandler.getCanvas()).thenReturn(canvas);
     }
 
@@ -136,12 +163,15 @@ public class ClientFullSessionTest {
                      tested.getDockingAcceptorControl());
         assertEquals(canvasInPlaceTextEditorControl,
                      tested.getCanvasInPlaceTextEditorControl());
-        assertEquals(dragControl,
-                     tested.getDragControl());
+        assertEquals(locationControl,
+                     tested.getLocationControl());
         assertEquals(toolboxControl,
                      tested.getToolboxControl());
         assertEquals(builderControl,
                      tested.getBuilderControl());
+        assertEquals(keyboardControl,
+                     tested.getKeyboardControl());
+
         // Assert setting the right command manager for each control.
         final ArgumentCaptor<RequiresCommandManager.CommandManagerProvider> conn =
                 ArgumentCaptor.forClass(RequiresCommandManager.CommandManagerProvider.class);
@@ -169,7 +199,7 @@ public class ClientFullSessionTest {
                      builder.getValue().getCommandManager());
         final ArgumentCaptor<RequiresCommandManager.CommandManagerProvider> drag =
                 ArgumentCaptor.forClass(RequiresCommandManager.CommandManagerProvider.class);
-        verify(dragControl,
+        verify(locationControl,
                times(1)).setCommandManagerProvider(drag.capture());
         assertEquals(requestCommandManager,
                      drag.getValue().getCommandManager());
@@ -211,12 +241,14 @@ public class ClientFullSessionTest {
                times(1)).enable(eq(canvasHandler));
         verify(canvasInPlaceTextEditorControl,
                times(1)).enable(eq(canvasHandler));
-        verify(dragControl,
+        verify(locationControl,
                times(1)).enable(eq(canvasHandler));
         verify(toolboxControl,
                times(1)).enable(eq(canvasHandler));
         verify(builderControl,
                times(1)).enable(eq(canvasHandler));
+        verify(keyboardControl,
+               times(1)).bind(eq(tested));
     }
 
     @Test
@@ -248,12 +280,14 @@ public class ClientFullSessionTest {
                times(1)).disable();
         verify(canvasInPlaceTextEditorControl,
                times(1)).disable();
-        verify(dragControl,
+        verify(locationControl,
                times(1)).disable();
         verify(toolboxControl,
                times(1)).disable();
         verify(builderControl,
                times(1)).disable();
+        verify(keyboardControl,
+               times(1)).unbind();
     }
 
     private void buildTestedInstance() {
