@@ -18,10 +18,12 @@ package org.kie.workbench.common.stunner.core.graph.processing.index.bounds;
 
 import java.util.List;
 import java.util.Optional;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.core.graph.Edge;
+import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
@@ -35,11 +37,10 @@ import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 @Dependent
 public class GraphBoundsIndexerImpl implements GraphBoundsIndexer {
 
+    ChildrenTraverseProcessor childrenTraverseProcessor;
     private Graph<View, Node<View, Edge>> graph;
     private String rootUUID = null;
 
-    ChildrenTraverseProcessor childrenTraverseProcessor;
-
     @Inject
     public GraphBoundsIndexerImpl(final ChildrenTraverseProcessor childrenTraverseProcessor) {
         this.childrenTraverseProcessor = childrenTraverseProcessor;
@@ -58,6 +59,44 @@ public class GraphBoundsIndexerImpl implements GraphBoundsIndexer {
                              y);
     }
 
+    @Override
+    public Node<View<?>, Edge> getAt(final double x,
+                                     final double y,
+                                     final double width,
+                                     final double height,
+                                     final Element parentNode) {
+        Point2D parentNodePosition;
+        double xToCheck = 0;
+        double yToCheck = 0;
+        if (parentNode != null) {
+            parentNodePosition=GraphUtils.getPosition((View) parentNode.asNode().getContent());
+            xToCheck = x + parentNodePosition.getX();
+            yToCheck = y + parentNodePosition.getY();
+        }
+        Node<View<?>, Edge> element;
+        Point2D[] pointsToCheck = new Point2D[5];
+        pointsToCheck[0] = new Point2D(xToCheck,
+                                       yToCheck);
+        pointsToCheck[1] = new Point2D(xToCheck + width,
+                                       yToCheck);
+        pointsToCheck[2] = new Point2D(xToCheck + (width / 2),
+                                       yToCheck + (height / 2));
+        pointsToCheck[3] = new Point2D(xToCheck,
+                                       yToCheck + height);
+        pointsToCheck[4] = new Point2D(xToCheck + width,
+                                       yToCheck + height);
+        for (Point2D point : pointsToCheck) {
+            element = findElementAt(point.getX(),
+                                    point.getY());
+            if (element != null) {
+                if (element != parentNode) {
+                    return element;
+                }
+            }
+        }
+        return null;
+    }
+
     @Override
     public double[] getTrimmedBounds() {
         final double[] result = new double[]{Double.MAX_VALUE, Double.MAX_VALUE, 0, 0};
@@ -122,56 +161,6 @@ public class GraphBoundsIndexerImpl implements GraphBoundsIndexer {
         return result[0];
     }
 
-    private abstract class NodeBoundsTraverseCallback {
-
-        public abstract void onNodeTraverse(final Node<View, Edge> node,
-                                            final double parentX,
-                                            final double parentY);
-    }
-
-    private class GraphBoundIndexerTraverseCallback extends AbstractChildrenTraverseCallback<Node<View, Edge>, Edge<Child, Node>> {
-
-        private final NodeBoundsTraverseCallback callback;
-
-        private GraphBoundIndexerTraverseCallback(final NodeBoundsTraverseCallback callback) {
-            this.callback = callback;
-        }
-
-        @Override
-        public void startNodeTraversal(final Node<View, Edge> node) {
-            super.startNodeTraversal(node);
-            onStartNodeTraversal(Optional.empty(),
-                                 node);
-        }
-
-        @Override
-        public boolean startNodeTraversal(final List<Node<View, Edge>> parents,
-                                          final Node<View, Edge> node) {
-            super.startNodeTraversal(parents,
-                                     node);
-            onStartNodeTraversal(Optional.ofNullable(parents),
-                                 node);
-            return true;
-        }
-
-        private void onStartNodeTraversal(final Optional<List<Node<View, Edge>>> parents,
-                                          final Node<View, Edge> node) {
-            final double[] parentLocation = {0, 0};
-            if (parents.isPresent()) {
-                parents.get().forEach(parent -> {
-                    final Point2D nodeCoordinates = getNodeCoordinates(parent);
-                    if (null != nodeCoordinates) {
-                        parentLocation[0] += nodeCoordinates.getX();
-                        parentLocation[1] += nodeCoordinates.getY();
-                    }
-                });
-            }
-            callback.onNodeTraverse(node,
-                                    parentLocation[0],
-                                    parentLocation[1]);
-        }
-    }
-
     private Point2D getNodeCoordinates(final Node node) {
         if (null != node) {
             final Object content = node.getContent();
@@ -231,4 +220,54 @@ public class GraphBoundsIndexerImpl implements GraphBoundsIndexer {
         this.rootUUID = null;
         this.childrenTraverseProcessor = null;
     }
+
+    private abstract class NodeBoundsTraverseCallback {
+
+        public abstract void onNodeTraverse(final Node<View, Edge> node,
+                                            final double parentX,
+                                            final double parentY);
+    }
+
+    private class GraphBoundIndexerTraverseCallback extends AbstractChildrenTraverseCallback<Node<View, Edge>, Edge<Child, Node>> {
+
+        private final NodeBoundsTraverseCallback callback;
+
+        private GraphBoundIndexerTraverseCallback(final NodeBoundsTraverseCallback callback) {
+            this.callback = callback;
+        }
+
+        @Override
+        public void startNodeTraversal(final Node<View, Edge> node) {
+            super.startNodeTraversal(node);
+            onStartNodeTraversal(Optional.empty(),
+                                 node);
+        }
+
+        @Override
+        public boolean startNodeTraversal(final List<Node<View, Edge>> parents,
+                                          final Node<View, Edge> node) {
+            super.startNodeTraversal(parents,
+                                     node);
+            onStartNodeTraversal(Optional.ofNullable(parents),
+                                 node);
+            return true;
+        }
+
+        private void onStartNodeTraversal(final Optional<List<Node<View, Edge>>> parents,
+                                          final Node<View, Edge> node) {
+            final double[] parentLocation = {0, 0};
+            if (parents.isPresent()) {
+                parents.get().forEach(parent -> {
+                    final Point2D nodeCoordinates = getNodeCoordinates(parent);
+                    if (null != nodeCoordinates) {
+                        parentLocation[0] += nodeCoordinates.getX();
+                        parentLocation[1] += nodeCoordinates.getY();
+                    }
+                });
+            }
+            callback.onNodeTraverse(node,
+                                    parentLocation[0],
+                                    parentLocation[1]);
+        }
+    }
 }
