@@ -20,6 +20,7 @@ import java.util.ArrayList;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
 import java.util.function.BiPredicate;
@@ -33,10 +34,11 @@ import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
 import org.kie.workbench.common.stunner.core.graph.content.relationship.Child;
+import org.kie.workbench.common.stunner.core.graph.content.relationship.Dock;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 public class GraphUtils {
 
@@ -222,6 +224,7 @@ public class GraphUtils {
 
     /**
      * Checks that the given Bounds do not exceed graph limits.
+     *
      * @return if bounds exceed graph limits it returns <code>false</code>. Otherwise returns <code>true</code>.
      */
     @SuppressWarnings("unchecked")
@@ -237,8 +240,9 @@ public class GraphUtils {
 
     /**
      * Finds the first node in the graph structure for the given type.
+     *
      * @param graph The graph structure.
-     * @param type The Definition type..
+     * @param type  The Definition type..
      */
     @SuppressWarnings("unchecked")
     public static <C> Node<Definition<C>, ?> getFirstNode(final Graph<?, Node> graph,
@@ -262,15 +266,18 @@ public class GraphUtils {
 
     @SuppressWarnings("unchecked")
     public static boolean hasChildren(final Node<?, ? extends Edge> element) {
-        final List<? extends Edge> outEdges = element.getOutEdges();
-        if (null != outEdges) {
-            return
-                    outEdges.stream()
-                            .filter(edge -> (edge.getContent() instanceof Child))
-                            .findAny()
-                            .isPresent();
-        }
-        return false;
+        return Objects.nonNull(element.getOutEdges()) ?
+                element.getOutEdges().stream()
+                        .anyMatch(edge -> (edge.getContent() instanceof Child)) :
+                false;
+    }
+
+    public static boolean hasDockedNodes(final Node<?, ? extends Edge> element) {
+        return Objects.nonNull(element.getOutEdges()) ?
+                element.getOutEdges()
+                        .stream()
+                        .allMatch(edge -> (edge.getContent() instanceof Dock)) :
+                false;
     }
 
     @SuppressWarnings("unchecked")
