@@ -32,11 +32,17 @@ import org.kie.workbench.common.stunner.core.rule.context.NodeDockingContext;
 import org.mockito.ArgumentCaptor;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyCardinality;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyDocking;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class AddDockedNodeCommandTest extends AbstractGraphCommandTest {
