@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.forms.client.widgets;
 import java.util.Collection;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -26,8 +27,8 @@ import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import com.google.gwt.logging.client.LogConfiguration;
-import com.google.gwt.user.client.ui.IsWidget;
-import com.google.gwt.user.client.ui.Widget;
+import org.jboss.errai.common.client.api.IsElement;
+import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.databinding.client.BindableProxy;
 import org.jboss.errai.databinding.client.BindableProxyFactory;
 import org.jboss.errai.databinding.client.HasProperties;
@@ -40,7 +41,7 @@ import org.kie.workbench.common.forms.dynamic.service.shared.impl.StaticModelFor
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
-import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasElementSelectedEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
@@ -57,13 +58,14 @@ import org.kie.workbench.common.stunner.forms.context.PathAwareFormContext;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.mvp.Command;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
 @Dependent
-public class FormPropertiesWidget implements IsWidget {
+public class FormPropertiesWidget implements IsElement, FormPropertiesWidgetView.Presenter {
 
     private static Logger LOGGER = Logger.getLogger(FormPropertiesWidget.class.getName());
 
+    private final FormPropertiesWidgetView view;
     private final DefinitionUtils definitionUtils;
     private final CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
     private final DynamicFormRenderer formRenderer;
@@ -74,19 +76,12 @@ public class FormPropertiesWidget implements IsWidget {
     private final DynamicFormModelGenerator modelGenerator;
 
     protected FormPropertiesWidget() {
-        this(null,
-             null,
-             null,
-             null,
-             null);
+        this(null, null, null, null, null, null);
     }
 
     @Inject
-    public FormPropertiesWidget(final DefinitionUtils definitionUtils,
-                                final CanvasCommandFactory<AbstractCanvasHandler> commandFactory,
-                                final DynamicFormRenderer formRenderer,
-                                final DynamicFormModelGenerator modelGenerator,
-                                final Event<FormPropertiesOpened> propertiesOpenedEvent) {
+    public FormPropertiesWidget(final FormPropertiesWidgetView view, final DefinitionUtils definitionUtils, final CanvasCommandFactory<AbstractCanvasHandler> commandFactory, final DynamicFormRenderer formRenderer, final DynamicFormModelGenerator modelGenerator, final Event<FormPropertiesOpened> propertiesOpenedEvent) {
+        this.view = view;
         this.definitionUtils = definitionUtils;
         this.commandFactory = commandFactory;
         this.formRenderer = formRenderer;
@@ -96,8 +91,18 @@ public class FormPropertiesWidget implements IsWidget {
 
     @PostConstruct
     public void init() {
-        log(Level.INFO,
-            "FormPropertiesWidget instance build.");
+        log(Level.INFO, "FormPropertiesWidget instance build.");
+        view.init(this);
+    }
+
+    @Override
+    public HTMLElement getElement() {
+        return view.getElement();
+    }
+
+    @Override
+    public DynamicFormRenderer getRenderer() {
+        return formRenderer;
     }
 
     /**
@@ -122,11 +127,11 @@ public class FormPropertiesWidget implements IsWidget {
     }
 
     /**
-     * Shows properties of elements in current session as:
-     * 1.- If any element selected on session control, show properties for it.
-     * 2.- If no element selected on session control:
-     * 2.1- If no canvas root fot the diagram, show the diagram's graph properties.
-     * 2.2- If diagram has a canvas root, show the properties for that element.
+     * Shows properties of elements in current session as: 1.- If any element
+     * selected on session control, show properties for it. 2.- If no element
+     * selected on session control: 2.1- If no canvas root fot the diagram, show the
+     * diagram's graph properties. 2.2- If diagram has a canvas root, show the
+     * properties for that element.
      */
     public void show() {
         this.show(null);
@@ -145,9 +150,7 @@ public class FormPropertiesWidget implements IsWidget {
                     selectedItemUUID = selectedItems.iterator().next();
                 }
             } else {
-                LOGGER.log(Level.WARNING,
-                           "Cannot show properties as session type does not provides " +
-                                   "selection control's support.");
+                LOGGER.log(Level.WARNING, "Cannot show properties as session type does not provides " + "selection control's support.");
             }
             if (null == selectedItemUUID) {
                 final Diagram<?, ?> diagram = getDiagram();
@@ -160,9 +163,7 @@ public class FormPropertiesWidget implements IsWidget {
                 }
             }
             if (null != selectedItemUUID) {
-                showByUUID(selectedItemUUID,
-                           getSessionRenderMode(),
-                           callback);
+                showByUUID(selectedItemUUID, getSessionRenderMode(), callback);
                 done = true;
             }
         }
@@ -174,38 +175,27 @@ public class FormPropertiesWidget implements IsWidget {
     /**
      * Show properties for the element with the given identifier.
      */
-    public void showByUUID(final String uuid,
-                           final RenderMode renderMode) {
-        this.showByUUID(uuid,
-                        renderMode,
-                        null);
+    public void showByUUID(final String uuid, final RenderMode renderMode) {
+        this.showByUUID(uuid, renderMode, null);
     }
 
     @SuppressWarnings("unchecked")
-    public void showByUUID(final String uuid,
-                           final RenderMode renderMode,
-                           final Command callback) {
-        final Element<? extends Definition<?>> element = (null != uuid && null != getCanvasHandler()) ?
-                getCanvasHandler().getGraphIndex().get(uuid) : null;
+    public void showByUUID(final String uuid, final RenderMode renderMode, final Command callback) {
+        final Element<? extends Definition<?>> element = (null != uuid && null != getCanvasHandler()) ? getCanvasHandler().getGraphIndex().get(uuid) : null;
         if (null != element) {
             final Object definition = element.getContent().getDefinition();
             final BindableProxy<?> proxy = (BindableProxy<?>) BindableProxyFactory.getBindableProxy(definition);
             final Path diagramPath = session.getCanvasHandler().getDiagram().getMetadata().getPath();
             final StaticModelFormRenderingContext generatedCtx = modelGenerator.getContextForModel(proxy.deepUnwrap());
-            final FormRenderingContext<?> pathAwareCtx = new PathAwareFormContext<>(generatedCtx,
-                                                                                    diagramPath);
+            final FormRenderingContext<?> pathAwareCtx = new PathAwareFormContext<>(generatedCtx, diagramPath);
             formRenderer.render(pathAwareCtx);
             formRenderer.addFieldChangeHandler((fieldName, newValue) -> {
                 try {
                     final HasProperties hasProperties = (HasProperties) DataBinder.forModel(definition).getModel();
-                    final String pId = getModifiedPropertyId(hasProperties,
-                                                             fieldName);
-                    FormPropertiesWidget.this.executeUpdateProperty(element,
-                                                                    pId,
-                                                                    newValue);
+                    final String pId = getModifiedPropertyId(hasProperties, fieldName);
+                    FormPropertiesWidget.this.executeUpdateProperty(element, pId, newValue);
                 } catch (final Exception ex) {
-                    log(Level.SEVERE,
-                        "Something wrong happened refreshing the canvas for field '" + fieldName + "': " + ex.getCause());
+                    log(Level.SEVERE, "Something wrong happened refreshing the canvas for field '" + fieldName + "': " + ex.getCause());
                 } finally {
                     if (null != callback) {
                         callback.execute();
@@ -214,9 +204,7 @@ public class FormPropertiesWidget implements IsWidget {
             });
 
             final String name = definitionUtils.getName(definition);
-            propertiesOpenedEvent.fire(new FormPropertiesOpened(session,
-                                                                uuid,
-                                                                name));
+            propertiesOpenedEvent.fire(new FormPropertiesOpened(session, uuid, name));
         } else {
             doClear();
             if (null != callback) {
@@ -225,11 +213,6 @@ public class FormPropertiesWidget implements IsWidget {
         }
     }
 
-    @Override
-    public Widget asWidget() {
-        return formRenderer.asWidget();
-    }
-
     private AbstractCanvasHandler getCanvasHandler() {
         return session != null ? (AbstractCanvasHandler) session.getCanvasHandler() : null;
     }
@@ -247,31 +230,32 @@ public class FormPropertiesWidget implements IsWidget {
     }
 
     @SuppressWarnings("unchecked")
-    void onCanvasElementSelectedEvent(@Observes CanvasElementSelectedEvent event) {
+    void onCanvasSelectionEvent(@Observes CanvasSelectionEvent event) {
         checkNotNull("event",
                      event);
         if (null != getCanvasHandler()) {
-            final String uuid = event.getElementUUID();
-            showByUUID(uuid,
-                       getSessionRenderMode());
+            if (event.getIdentifiers().size() == 1) {
+                final String uuid = event.getIdentifiers().iterator().next();
+                showByUUID(uuid,
+                           getSessionRenderMode());
+            } else {
+                doClear();
+            }
         }
     }
 
     void CanvasClearSelectionEvent(@Observes CanvasClearSelectionEvent clearSelectionEvent) {
-        checkNotNull("clearSelectionEvent",
-                     clearSelectionEvent);
+        checkNotNull("clearSelectionEvent", clearSelectionEvent);
         doClear();
     }
 
     void onCanvasSessionOpened(@Observes SessionOpenedEvent sessionOpenedEvent) {
-        checkNotNull("sessionOpenedEvent",
-                     sessionOpenedEvent);
+        checkNotNull("sessionOpenedEvent", sessionOpenedEvent);
         doOpenSession(sessionOpenedEvent.getSession());
     }
 
     void onCanvasSessionDestroyed(@Observes SessionDestroyedEvent sessionDestroyedEvent) {
-        checkNotNull("sessionDestroyedEvent",
-                     sessionDestroyedEvent);
+        checkNotNull("sessionDestroyedEvent", sessionDestroyedEvent);
         unbind();
     }
 
@@ -280,50 +264,40 @@ public class FormPropertiesWidget implements IsWidget {
             bind(session).show();
         } catch (ClassCastException e) {
             // No writteable session. Do not show properties until read mode available.
-            log(Level.INFO,
-                "Session discarded for opening as not instance of full session.");
+            log(Level.INFO, "Session discarded for opening as not instance of full session.");
         }
     }
 
     private void doClear() {
+        if (formRenderer.isValid()) {
+            formRenderer.forceModelSynchronization();
+        }
         formRenderer.unBind();
     }
 
     @SuppressWarnings("unchecked")
-    private void executeUpdateProperty(final Element<? extends Definition<?>> element,
-                                       final String propertyId,
-                                       final Object value) {
+    private void executeUpdateProperty(final Element<? extends Definition<?>> element, final String propertyId, final Object value) {
         final CanvasCommandManager<AbstractCanvasHandler> commandManager = featuresSessionProvider.getCommandManager(session);
         if (null != commandManager) {
-            commandManager.execute(getCanvasHandler(),
-                                   commandFactory.updatePropertyValue(element,
-                                                                      propertyId,
-                                                                      value));
+            commandManager.execute(getCanvasHandler(), commandFactory.updatePropertyValue(element, propertyId, value));
         } else {
-            LOGGER.log(Level.WARNING,
-                       "Cannot update property [" + propertyId + "] as session type is not supported.");
+            LOGGER.log(Level.WARNING, "Cannot update property [" + propertyId + "] as session type is not supported.");
         }
     }
 
-    private String getModifiedPropertyId(HasProperties model,
-                                         String fieldName) {
+    private String getModifiedPropertyId(HasProperties model, String fieldName) {
         int separatorIndex = fieldName.indexOf(".");
-        // Check if it is a nested property, if it is we must obtain the nested property instead of the root one.
+        // Check if it is a nested property, if it is we must obtain the nested property
+        // instead of the root one.
         if (separatorIndex != -1) {
-            String rootProperty = fieldName.substring(0,
-                                                      separatorIndex);
+            String rootProperty = fieldName.substring(0, separatorIndex);
             fieldName = fieldName.substring(separatorIndex + 1);
             Object property = model.get(rootProperty);
             model = (HasProperties) DataBinder.forModel(property).getModel();
-            return getModifiedPropertyId(model,
-                                         fieldName);
+            return getModifiedPropertyId(model, fieldName);
         }
         Object property = model.get(fieldName);
-        return definitionUtils
-                .getDefinitionManager()
-                .adapters()
-                .forProperty()
-                .getId(property);
+        return definitionUtils.getDefinitionManager().adapters().forProperty().getId(property);
     }
 
     private FormFeaturesSessionProvider getFeaturesSessionProvider(final ClientSession session) {
@@ -338,13 +312,11 @@ public class FormPropertiesWidget implements IsWidget {
     /**
      * An ORDERED array of feature providers supported.
      */
-    private static final FormFeaturesSessionProvider[] FEATURE_SESSION_PROVIDERS =
-            new FormFeaturesSessionProvider[]{
-                    new FormFeaturesFullSessionProvider(),
-                    new FormFeaturesReadOnlySessionProvider()};
+    private static final FormFeaturesSessionProvider[] FEATURE_SESSION_PROVIDERS = new FormFeaturesSessionProvider[]{new FormFeaturesFullSessionProvider(), new FormFeaturesReadOnlySessionProvider()};
 
     /**
-     * This type provides required features that are specific for concrete client session types.
+     * This type provides required features that are specific for concrete client
+     * session types.
      */
     private interface FormFeaturesSessionProvider<S extends ClientSession> {
 
@@ -354,12 +326,14 @@ public class FormPropertiesWidget implements IsWidget {
         boolean supports(ClientSession type);
 
         /**
-         * Returns the session's selection control instance, if not available, it returns <code>null</code>.
+         * Returns the session's selection control instance, if not available, it
+         * returns <code>null</code>.
          */
         SelectionControl getSelectionControl(S session);
 
         /**
-         * Returns the session's command manager instance, if not available, it returns <code>null</code>.
+         * Returns the session's command manager instance, if not available, it returns
+         * <code>null</code>.
          */
         CanvasCommandManager<AbstractCanvasHandler> getCommandManager(S session);
     }
@@ -412,11 +386,9 @@ public class FormPropertiesWidget implements IsWidget {
         return s == null || s.trim().length() == 0;
     }
 
-    private void log(final Level level,
-                     final String message) {
+    private void log(final Level level, final String message) {
         if (LogConfiguration.loggingIsEnabled()) {
-            LOGGER.log(level,
-                       message);
+            LOGGER.log(level, message);
         }
     }
 }
