@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.forms.client.widgets;
 
 import java.util.ArrayList;
 import java.util.Collection;
+
 import javax.enterprise.event.Event;
 
 import org.jboss.errai.databinding.client.BindableProxy;
@@ -48,10 +49,14 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.mvp.Command;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.anyObject;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class FormPropertiesWidgetTest {
@@ -59,6 +64,8 @@ public class FormPropertiesWidgetTest {
     private static final String DIAGRAM_NAME = "diagram1";
     private static final String ROOT_UUID = "root1";
 
+    @Mock
+    private FormPropertiesWidgetView view;
     @Mock
     DefinitionUtils definitionUtils;
     @Mock
@@ -115,7 +122,8 @@ public class FormPropertiesWidgetTest {
         when(proxyProvider.getBindableProxy()).thenReturn((BindableProxy) proxy);
         when(proxyProvider.getBindableProxy(unmockedDef)).thenReturn((BindableProxy) proxy);
         when(proxy.deepUnwrap()).thenReturn(unmockedDef);
-        this.tested = new FormPropertiesWidget(definitionUtils,
+        this.tested = new FormPropertiesWidget(view,
+                                               definitionUtils,
                                                commandFactory,
                                                formRenderer,
                                                modelGenerator,
