@@ -34,9 +34,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGen
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.ReusableSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
@@ -51,12 +50,6 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 )
 public class AdHocSubprocess extends BaseSubprocess implements DataIOModel {
 
-    @Title
-    public static final transient String title = "Adhoc Sub-Process";
-
-    @Description
-    public static final transient String description = "A reusable Sub-Process. It can be used to invoke another process.";
-
     @PropertySet
     @FormField(
             afterElement = "general"
@@ -72,7 +65,7 @@ public class AdHocSubprocess extends BaseSubprocess implements DataIOModel {
     protected DataIOSet dataIOSet;
 
     @NonPortable
-    public static class AdHocSubprocessBuilder extends BaseSubprocessBuilder<AdHocSubprocess> {
+    public static class AdHocSubprocessBuilder implements Builder<AdHocSubprocess> {
 
         @Override
         public AdHocSubprocess build() {
@@ -80,12 +73,9 @@ public class AdHocSubprocess extends BaseSubprocess implements DataIOModel {
                     new BPMNGeneralSet("Subprocess"),
                     new ReusableSubprocessTaskExecutionSet(),
                     new DataIOSet(),
-                    new BackgroundSet(COLOR,
-                                      BORDER_COLOR,
-                                      BORDER_SIZE),
+                    new BackgroundSet(),
                     new FontSet(),
-                    new RectangleDimensionsSet(WIDTH,
-                                               HEIGHT),
+                    new RectangleDimensionsSet(),
                     new SimulationSet());
         }
     }
@@ -130,11 +120,6 @@ public class AdHocSubprocess extends BaseSubprocess implements DataIOModel {
         return false;
     }
 
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
     public ReusableSubprocessTaskExecutionSet getExecutionSet() {
         return executionSet;
     }
