@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
@@ -26,21 +27,17 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
-public abstract class BaseConnector implements BPMNDefinition {
+public abstract class BaseConnector implements BPMNViewDefinition {
 
     @Category
     public static final transient String category = Categories.CONNECTING_OBJECTS;
 
-    @Description
-    public static final transient String description = "A Connecting Object";
-
     @PropertySet
     @FormField
     @Valid
@@ -84,10 +81,6 @@ public abstract class BaseConnector implements BPMNDefinition {
         return category;
     }
 
-    public String getDescription() {
-        return description;
-    }
-
     public Set<String> getLabels() {
         return labels;
     }
