@@ -18,105 +18,76 @@ package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
-import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOModel;
-import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.ThrowEventAttributes;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
-@MorphBase(defaultType = EndNoneEvent.class
-        /* TODO: Disabled morphing from end to start events for M1
-        targets = { BaseStartEvent.class } */
-)
-public abstract class BaseEndEvent implements BPMNDefinition,
+@MorphBase(defaultType = EndNoneEvent.class)
+public abstract class BaseEndEvent implements BPMNViewDefinition,
                                               DataIOModel {
 
     @Category
     public static final transient String category = Categories.EVENTS;
-
+    @Labels
+    protected final Set<String> labels = new HashSet<String>();
     @PropertySet
     @FormField
     @Valid
     protected BPMNGeneralSet general;
-
-    @PropertySet
-    @FormField(
-            afterElement = "general"
-    )
-    @Valid
-    protected DataIOSet dataIOSet;
-
     @PropertySet
     @Valid
     protected BackgroundSet backgroundSet;
-
-    @PropertySet
-    protected ThrowEventAttributes throwEventAttributes;
-
     @PropertySet
     protected FontSet fontSet;
-
     @PropertySet
     protected CircleDimensionSet dimensionsSet;
 
-    @Labels
-    protected final Set<String> labels = new HashSet<String>() {{
-        add("all");
-        add("sequence_end");
-        add("to_task_event");
-        add("from_task_event");
-        add("fromtoall");
-        add("choreography_sequence_end");
-        add("Endevents_all");
-        add("EndEventsMorph");
-        add("cm_nop");
-    }};
-
-    static abstract class BaseEndEventBuilder<T extends BaseEndEvent> implements Builder<T> {
-
-        public static final String BG_COLOR = "#ff6347";
-        public static final Double BORDER_SIZE = 1.5d;
-        public static final String BORDER_COLOR = "#000000";
-        public static final Double RADIUS = 14d;
-    }
-
     public BaseEndEvent() {
+        initLabels();
     }
 
-    public BaseEndEvent(final @MapsTo("general") BPMNGeneralSet general,
-                        final @MapsTo("dataIOSet") DataIOSet dataIOSet,
-                        final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
-                        final @MapsTo("fontSet") FontSet fontSet,
-                        final @MapsTo("throwEventAttributes") ThrowEventAttributes throwEventAttributes,
-                        final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet) {
+    public BaseEndEvent(final BPMNGeneralSet general,
+                        final BackgroundSet backgroundSet,
+                        final FontSet fontSet,
+                        final CircleDimensionSet dimensionsSet) {
+        this();
         this.general = general;
-        this.dataIOSet = dataIOSet;
         this.backgroundSet = backgroundSet;
         this.fontSet = fontSet;
-        this.throwEventAttributes = throwEventAttributes;
         this.dimensionsSet = dimensionsSet;
     }
 
+    protected void initLabels() {
+        labels.add("all");
+        labels.add("sequence_end");
+        labels.add("to_task_event");
+        labels.add("from_task_event");
+        labels.add("fromtoall");
+        labels.add("choreography_sequence_end");
+        labels.add("Endevents_all");
+        labels.add("EndEventsMorph");
+        labels.add("cm_nop");
+    }
+
     @Override
     public boolean hasInputVars() {
-        return true;
+        return false;
     }
 
     @Override
     public boolean isSingleInputVar() {
-        return true;
+        return false;
     }
 
     @Override
@@ -141,36 +112,20 @@ public abstract class BaseEndEvent implements BPMNDefinition,
         return general;
     }
 
-    public DataIOSet getDataIOSet() {
-        return dataIOSet;
+    public void setGeneral(final BPMNGeneralSet general) {
+        this.general = general;
     }
 
     public BackgroundSet getBackgroundSet() {
         return backgroundSet;
     }
 
-    public FontSet getFontSet() {
-        return fontSet;
-    }
-
-    public ThrowEventAttributes getThrowEventAttributes() {
-        return throwEventAttributes;
-    }
-
-    public void setGeneral(final BPMNGeneralSet general) {
-        this.general = general;
-    }
-
-    public void setDataIOSet(final DataIOSet dataIOSet) {
-        this.dataIOSet = dataIOSet;
-    }
-
     public void setBackgroundSet(final BackgroundSet backgroundSet) {
         this.backgroundSet = backgroundSet;
     }
 
-    public void setThrowEventAttributes(final ThrowEventAttributes throwEventAttributes) {
-        this.throwEventAttributes = throwEventAttributes;
+    public FontSet getFontSet() {
+        return fontSet;
     }
 
     public void setFontSet(final FontSet fontSet) {
@@ -188,9 +143,7 @@ public abstract class BaseEndEvent implements BPMNDefinition,
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(general.hashCode(),
-                                         dataIOSet.hashCode(),
                                          backgroundSet.hashCode(),
-                                         throwEventAttributes.hashCode(),
                                          fontSet.hashCode(),
                                          dimensionsSet.hashCode());
     }
@@ -200,9 +153,7 @@ public abstract class BaseEndEvent implements BPMNDefinition,
         if (o instanceof BaseEndEvent) {
             BaseEndEvent other = (BaseEndEvent) o;
             return general.equals(other.general) &&
-                    dataIOSet.equals(other.dataIOSet) &&
                     backgroundSet.equals(other.backgroundSet) &&
-                    throwEventAttributes.equals(other.throwEventAttributes) &&
                     fontSet.equals(other.fontSet) &&
                     dimensionsSet.equals(other.dimensionsSet);
         }
