@@ -18,48 +18,37 @@ package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
-import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOModel;
-import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.CatchEventAttributes;
+import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
-@MorphBase(defaultType = StartNoneEvent.class
-        /* TODO: Disabled morphing from start to end events for M1
-        targets = { BaseEndEvent.class } */
-)
-public abstract class BaseStartEvent implements BPMNDefinition,
+@MorphBase(defaultType = StartNoneEvent.class)
+public abstract class BaseStartEvent implements BPMNViewDefinition,
                                                 DataIOModel {
 
     @Category
     public static final transient String category = Categories.EVENTS;
 
+    @Labels
+    protected final Set<String> labels = new HashSet<String>();
+
     @PropertySet
     @FormField
     @Valid
     protected BPMNGeneralSet general;
 
-    @PropertySet
-    @FormField(
-            afterElement = "general",
-            labelKey = "dataIOSet"
-    )
-    @Valid
-    protected DataIOSet dataIOSet;
-
     @PropertySet
     @Valid
     protected BackgroundSet backgroundSet;
@@ -67,50 +56,40 @@ public abstract class BaseStartEvent implements BPMNDefinition,
     @PropertySet
     protected FontSet fontSet;
 
-    @PropertySet
-    protected CatchEventAttributes catchEventAttributes;
-
     @PropertySet
     private CircleDimensionSet dimensionsSet;
 
-    @Labels
-    protected final Set<String> labels = new HashSet<String>() {{
-        add("all");
-        add("Startevents_all");
-        add("Startevents_outgoing_all");
-        add("sequence_start");
-        add("choreography_sequence_start");
-        add("to_task_event");
-        add("from_task_event");
-        add("fromtoall");
-        add("StartEventsMorph");
-        add("cm_nop");
-    }};
-
-    @NonPortable
-    static abstract class BaseStartEventBuilder<T extends BaseStartEvent> implements Builder<T> {
-
-        public static final String BG_COLOR = "#9acd32";
-        public static final Double BORDER_SIZE = 1.5d;
-        public static final String BORDER_COLOR = "#000000";
-        public static final Double RADIUS = 15d;
-    }
+    @PropertySet
+    private SimulationAttributeSet simulationSet;
 
     public BaseStartEvent() {
+        initLabels();
     }
 
-    public BaseStartEvent(final @MapsTo("general") BPMNGeneralSet general,
-                          final @MapsTo("dataIOSet") DataIOSet dataIOSet,
-                          final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
-                          final @MapsTo("fontSet") FontSet fontSet,
-                          final @MapsTo("catchEventAttributes") CatchEventAttributes catchEventAttributes,
-                          final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet) {
+    public BaseStartEvent(final BPMNGeneralSet general,
+                          final BackgroundSet backgroundSet,
+                          final FontSet fontSet,
+                          final CircleDimensionSet dimensionsSet,
+                          final SimulationAttributeSet simulationSet) {
+        this();
         this.general = general;
-        this.dataIOSet = dataIOSet;
         this.backgroundSet = backgroundSet;
         this.fontSet = fontSet;
-        this.catchEventAttributes = catchEventAttributes;
         this.dimensionsSet = dimensionsSet;
+        this.simulationSet = simulationSet;
+    }
+
+    protected void initLabels() {
+        labels.add("all");
+        labels.add("Startevents_all");
+        labels.add("Startevents_outgoing_all");
+        labels.add("sequence_start");
+        labels.add("choreography_sequence_start");
+        labels.add("to_task_event");
+        labels.add("from_task_event");
+        labels.add("fromtoall");
+        labels.add("StartEventsMorph");
+        labels.add("cm_nop");
     }
 
     @Override
@@ -125,12 +104,12 @@ public abstract class BaseStartEvent implements BPMNDefinition,
 
     @Override
     public boolean hasOutputVars() {
-        return true;
+        return false;
     }
 
     @Override
     public boolean isSingleOutputVar() {
-        return true;
+        return false;
     }
 
     public String getCategory() {
@@ -145,10 +124,6 @@ public abstract class BaseStartEvent implements BPMNDefinition,
         return general;
     }
 
-    public DataIOSet getDataIOSet() {
-        return dataIOSet;
-    }
-
     public BackgroundSet getBackgroundSet() {
         return backgroundSet;
     }
@@ -157,18 +132,10 @@ public abstract class BaseStartEvent implements BPMNDefinition,
         return fontSet;
     }
 
-    public CatchEventAttributes getCatchEventAttributes() {
-        return catchEventAttributes;
-    }
-
     public void setGeneral(final BPMNGeneralSet general) {
         this.general = general;
     }
 
-    public void setDataIOSet(final DataIOSet dataIOSet) {
-        this.dataIOSet = dataIOSet;
-    }
-
     public void setBackgroundSet(final BackgroundSet backgroundSet) {
         this.backgroundSet = backgroundSet;
     }
@@ -177,10 +144,6 @@ public abstract class BaseStartEvent implements BPMNDefinition,
         this.fontSet = fontSet;
     }
 
-    public void setCatchEventAttributes(final CatchEventAttributes catchEventAttributes) {
-        this.catchEventAttributes = catchEventAttributes;
-    }
-
     public CircleDimensionSet getDimensionsSet() {
         return dimensionsSet;
     }
@@ -189,14 +152,21 @@ public abstract class BaseStartEvent implements BPMNDefinition,
         this.dimensionsSet = dimensionsSet;
     }
 
+    public SimulationAttributeSet getSimulationSet() {
+        return simulationSet;
+    }
+
+    public void setSimulationSet(SimulationAttributeSet simulationSet) {
+        this.simulationSet = simulationSet;
+    }
+
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(general.hashCode(),
-                                         dataIOSet.hashCode(),
                                          backgroundSet.hashCode(),
                                          fontSet.hashCode(),
-                                         catchEventAttributes.hashCode(),
-                                         dimensionsSet.hashCode());
+                                         dimensionsSet.hashCode(),
+                                         simulationSet.hashCode());
     }
 
     @Override
@@ -204,11 +174,10 @@ public abstract class BaseStartEvent implements BPMNDefinition,
         if (o instanceof BaseStartEvent) {
             BaseStartEvent other = (BaseStartEvent) o;
             return general.equals(other.general) &&
-                    dataIOSet.equals(other.dataIOSet) &&
                     backgroundSet.equals(other.backgroundSet) &&
                     fontSet.equals(other.fontSet) &&
-                    catchEventAttributes.equals(other.catchEventAttributes) &&
-                    dimensionsSet.equals(other.dimensionsSet);
+                    dimensionsSet.equals(other.dimensionsSet) &&
+                    simulationSet.equals(other.simulationSet);
         }
         return false;
     }
