@@ -17,33 +17,28 @@ package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.RectangleDimensionsSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationSet;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @MorphBase(defaultType = ReusableSubprocess.class, targets = {BaseTask.class})
-public abstract class BaseSubprocess implements BPMNDefinition {
+public abstract class BaseSubprocess implements BPMNViewDefinition {
 
     @Category
     public static final transient String category = Categories.ACTIVITIES;
 
-    @Description
-    public static final transient String description = "A subprocess is a decomposable activity.";
-
     @PropertySet
     @FormField
     @Valid
@@ -65,16 +60,6 @@ public abstract class BaseSubprocess implements BPMNDefinition {
     @Labels
     protected final Set<String> labels = new HashSet<>();
 
-    @NonPortable
-    public static abstract class BaseSubprocessBuilder<T extends BaseSubprocess> implements Builder<T> {
-
-        public static final String COLOR = "#fafad2";
-        public static final Double WIDTH = 136d;
-        public static final Double HEIGHT = 48d;
-        public static final Double BORDER_SIZE = 1d;
-        public static final String BORDER_COLOR = "#000000";
-    }
-
     protected BaseSubprocess() {
         this.labels.addAll(makeLabels());
     }
@@ -111,10 +96,6 @@ public abstract class BaseSubprocess implements BPMNDefinition {
         return category;
     }
 
-    public String getDescription() {
-        return description;
-    }
-
     public BPMNGeneralSet getGeneral() {
         return general;
     }
