@@ -38,8 +38,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskType;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskTypes;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
@@ -55,9 +55,6 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 )
 public class BusinessRuleTask extends BaseTask implements DataIOModel {
 
-    @Title
-    public static final transient String title = "Business Rule Task";
-
     @PropertySet
     @FormField(
             afterElement = "general"
@@ -73,7 +70,7 @@ public class BusinessRuleTask extends BaseTask implements DataIOModel {
     protected DataIOSet dataIOSet;
 
     @NonPortable
-    public static class BusinessRuleTaskBuilder extends BaseTaskBuilder<BusinessRuleTask> {
+    public static class BusinessRuleTaskBuilder implements Builder<BusinessRuleTask> {
 
         @Override
         public BusinessRuleTask build() {
@@ -81,12 +78,9 @@ public class BusinessRuleTask extends BaseTask implements DataIOModel {
                                                            new Documentation("")),
                                         new BusinessRuleTaskExecutionSet(),
                                         new DataIOSet(),
-                                        new BackgroundSet(COLOR,
-                                                          BORDER_COLOR,
-                                                          BORDER_SIZE),
+                                        new BackgroundSet(),
                                         new FontSet(),
-                                        new RectangleDimensionsSet(WIDTH,
-                                                                   HEIGHT),
+                                        new RectangleDimensionsSet(),
                                         new SimulationSet(),
                                         new TaskType(TaskTypes.BUSINESS_RULE)
             );
@@ -135,11 +129,6 @@ public class BusinessRuleTask extends BaseTask implements DataIOModel {
         return false;
     }
 
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
     public BusinessRuleTaskExecutionSet getExecutionSet() {
         return executionSet;
     }
