@@ -41,13 +41,13 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptLang
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.bpmn.forms.model.ConditionalComboBoxFieldType;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
+import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @Portable
@@ -55,35 +55,28 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 @Definition(graphFactory = NodeFactory.class, builder = EmbeddedSubprocess.EmbeddedSubprocessBuilder.class)
 @Morph(base = BaseSubprocess.class)
 @CanContain(roles = {"all"})
+@CanDock(roles = {"IntermediateEventOnSubprocessBoundary"})
 @FormDefinition(
         startElement = "general",
         policy = FieldPolicy.ONLY_MARKED
 )
 public class EmbeddedSubprocess extends BaseSubprocess implements DataIOModel {
 
-    @Title
-    public static final transient String title = "Embedded Sub-Process";
-
-    @Description
-    public static final transient String description = "An embedded sub-process.";
-
     @NonPortable
-    public static class EmbeddedSubprocessBuilder extends BaseSubprocessBuilder<EmbeddedSubprocess> {
+    public static class EmbeddedSubprocessBuilder implements Builder<EmbeddedSubprocess> {
 
+        // TODO: It should use #FAFAFA as bg_color, rather than other subprocesses...
         @Override
         public EmbeddedSubprocess build() {
             return new EmbeddedSubprocess(
                     new BPMNGeneralSet("Sub-process"),
-                    new BackgroundSet("#FFFFFF",
-                                      BORDER_COLOR,
-                                      BORDER_SIZE),
+                    new BackgroundSet(),
                     new FontSet(),
-                    new RectangleDimensionsSet(450d,
-                                               250d),
+                    new RectangleDimensionsSet(),
                     new SimulationSet(),
                     new OnEntryAction(""),
                     new OnExitAction(""),
-                    new ScriptLanguage(""),
+                    new ScriptLanguage(),
                     new IsAsync(),
                     new ProcessData());
         }
@@ -100,21 +93,21 @@ public class EmbeddedSubprocess extends BaseSubprocess implements DataIOModel {
 
     @Property
     @FormField(
-        type = TextAreaFieldType.class,
-        afterElement = "onEntryAction",
-        settings = {@FieldParam(name = "rows", value = "5")}
+            type = TextAreaFieldType.class,
+            afterElement = "onEntryAction",
+            settings = {@FieldParam(name = "rows", value = "5")}
     )
     @Valid
     private OnExitAction onExitAction;
 
     @Property
     @FormField(
-        type = ConditionalComboBoxFieldType.class,
-        afterElement = "onExitAction",
-        settings = {
-            @FieldParam(name = "relatedField", value = "onEntryAction;onExitAction"),
-            @FieldParam(name = "allowCustomValue", value = "false")
-        }
+            type = ConditionalComboBoxFieldType.class,
+            afterElement = "onExitAction",
+            settings = {
+                    @FieldParam(name = "relatedField", value = "onEntryAction;onExitAction"),
+                    @FieldParam(name = "allowCustomValue", value = "false")
+            }
     )
     @SelectorDataProvider(
             type = SelectorDataProvider.ProviderType.REMOTE,
@@ -151,10 +144,10 @@ public class EmbeddedSubprocess extends BaseSubprocess implements DataIOModel {
                               final @MapsTo("isAsync") IsAsync isAsync,
                               final @MapsTo("processData") ProcessData processData) {
         super(general,
-                backgroundSet,
-                fontSet,
-                dimensionsSet,
-                simulationSet);
+              backgroundSet,
+              fontSet,
+              dimensionsSet,
+              simulationSet);
         this.onEntryAction = onEntryAction;
         this.onExitAction = onExitAction;
         this.scriptLanguage = scriptLanguage;
@@ -182,10 +175,6 @@ public class EmbeddedSubprocess extends BaseSubprocess implements DataIOModel {
         return false;
     }
 
-    public String getTitle() {
-        return title;
-    }
-
     public ProcessData getProcessData() {
         return processData;
     }
