@@ -23,16 +23,14 @@ import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radius;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
-import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.CatchEventAttributes;
+import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 
 @Portable
@@ -45,25 +43,16 @@ import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 )
 public class StartNoneEvent extends BaseStartEvent {
 
-    @Title
-    public static final transient String title = "Start Event";
-
-    @Description
-    public static final transient String description = "Untyped start event";
-
     @NonPortable
-    public static class StartNoneEventBuilder extends BaseStartEventBuilder<StartNoneEvent> {
+    public static class StartNoneEventBuilder implements Builder<StartNoneEvent> {
 
         @Override
         public StartNoneEvent build() {
             return new StartNoneEvent(new BPMNGeneralSet(""),
-                                      new DataIOSet(),
-                                      new BackgroundSet(BG_COLOR,
-                                                        BORDER_COLOR,
-                                                        BORDER_SIZE),
+                                      new BackgroundSet(),
                                       new FontSet(),
-                                      new CatchEventAttributes(),
-                                      new CircleDimensionSet(new Radius(RADIUS)));
+                                      new CircleDimensionSet(new Radius()),
+                                      new SimulationAttributeSet());
         }
     }
 
@@ -71,25 +60,14 @@ public class StartNoneEvent extends BaseStartEvent {
     }
 
     public StartNoneEvent(final @MapsTo("general") BPMNGeneralSet general,
-                          final @MapsTo("dataIOSet") DataIOSet dataIOSet,
                           final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
                           final @MapsTo("fontSet") FontSet fontSet,
-                          final @MapsTo("catchEventAttributes") CatchEventAttributes catchEventAttributes,
-                          final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet) {
+                          final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
+                          final @MapsTo("simulationSet") SimulationAttributeSet simulationSet) {
         super(general,
-              dataIOSet,
               backgroundSet,
               fontSet,
-              catchEventAttributes,
-              dimensionsSet);
-    }
-
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
-    public String getDescription() {
-        return description;
+              dimensionsSet,
+              simulationSet);
     }
 }
