@@ -24,6 +24,7 @@ import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
+import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldDefinition;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOModel;
@@ -38,8 +39,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskTypes;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.UserTaskExecutionSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
@@ -55,9 +56,6 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 )
 public class UserTask extends BaseTask implements DataIOModel {
 
-    @Title
-    public static final transient String title = "User Task";
-
     @PropertySet
     @FormField(
             afterElement = "general"
@@ -66,19 +64,16 @@ public class UserTask extends BaseTask implements DataIOModel {
     protected UserTaskExecutionSet executionSet;
 
     @NonPortable
-    public static class UserTaskBuilder extends BaseTaskBuilder<UserTask> {
+    public static class UserTaskBuilder implements Builder<UserTask> {
 
         @Override
         public UserTask build() {
             return new UserTask(new TaskGeneralSet(new Name("Task"),
                                                    new Documentation("")),
                                 new UserTaskExecutionSet(),
-                                new BackgroundSet(COLOR,
-                                                  BORDER_COLOR,
-                                                  BORDER_SIZE),
+                                new BackgroundSet(),
                                 new FontSet(),
-                                new RectangleDimensionsSet(WIDTH,
-                                                           HEIGHT),
+                                new RectangleDimensionsSet(),
                                 new SimulationSet(),
                                 new TaskType(TaskTypes.USER));
         }
@@ -124,11 +119,6 @@ public class UserTask extends BaseTask implements DataIOModel {
         return false;
     }
 
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
     public UserTaskExecutionSet getExecutionSet() {
         return executionSet;
     }
