@@ -21,10 +21,8 @@ import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldLabel;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.slider.type.SliderFieldType;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.Name;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 
@@ -34,10 +32,6 @@ import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 @FormDefinition
 public class CircleDimensionSet implements BPMNPropertySet {
 
-    @Name
-    @FieldLabel
-    public static final transient String propertySetName = "Shape Dimensions";
-
     @Property
     @FormField(
             type = SliderFieldType.class,
