@@ -21,7 +21,7 @@ import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldLabel;
+import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.textArea.type.TextAreaFieldType;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNBaseInfo;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
@@ -35,11 +35,8 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 @FormDefinition(
         startElement = "name"
 )
-public class BPMNGeneralSet implements BPMNPropertySet, BPMNBaseInfo {
-
-    @org.kie.workbench.common.stunner.core.definition.annotation.Name
-    @FieldLabel
-    public static final transient String propertySetName = "General";
+public class BPMNGeneralSet implements BPMNPropertySet,
+                                       BPMNBaseInfo {
 
     @Property
     @FormField
@@ -74,10 +71,6 @@ public class BPMNGeneralSet implements BPMNPropertySet, BPMNBaseInfo {
         this.documentation = new Documentation();
     }
 
-    public String getPropertySetName() {
-        return propertySetName;
-    }
-
     @Override
     public Name getName() {
         return name;
