@@ -79,6 +79,8 @@ public class BpmnProcessDataEventListener
         return process;
     }
 
+    private Set<String> uniqueVariables;
+
     // ProcessDataEventListener methods -------------------------------------------------------------------------------------------
 
     @Override
@@ -242,25 +244,9 @@ public class BpmnProcessDataEventListener
         // process unqualified classes
         resolveUnqualifiedClasses();
 
-        // process variables
-        if (variables != null) {
-            for (Variable data : variables) {
-                String type = data.getType().getStringType();
-                String itemSubjectRef = (String) data.getMetaData("ItemSubjectRef");
-                if (itemSubjectRef != null && itemDefinitions != null) {
-                    ItemDefinition itemDef = itemDefinitions.get(itemSubjectRef);
-                    type = itemDef.getStructureRef();
-                }
-
-                resource.addPart(data.getName(),
-                                 PartType.VARIABLE);
-                if (type.contains(".")) {
-                    getReferencedClasses().add(type);
-                } else {
-                    getUnqualifiedClasses().add(type);
-                }
-            }
-        }
+        // distinct process variables (in case of duplicates)
+        addDistinctProcessVariables(variables,
+                                    resource);
 
         // process signals, messages, etc.
         visitSignals(signals);
@@ -281,6 +267,32 @@ public class BpmnProcessDataEventListener
         }
     }
 
+    public void addDistinctProcessVariables(List<Variable> variables,
+                                            Resource resource) {
+        if (variables != null) {
+            uniqueVariables = new HashSet<>();
+            for (Variable data : variables) {
+                String type = data.getType().getStringType();
+                String itemSubjectRef = (String) data.getMetaData("ItemSubjectRef");
+                if (itemSubjectRef != null && itemDefinitions != null) {
+                    ItemDefinition itemDef = itemDefinitions.get(itemSubjectRef);
+                    type = itemDef.getStructureRef();
+                }
+
+                // add only if unique
+                if (uniqueVariables.add(data.getName())) {
+                    resource.addPart(data.getName(),
+                                     PartType.VARIABLE);
+                }
+                if (type.contains(".")) {
+                    getReferencedClasses().add(type);
+                } else {
+                    getUnqualifiedClasses().add(type);
+                }
+            }
+        }
+    }
+
     private void visitSignals(Collection<String> signals) {
         if (signals != null) {
             for (String signal : signals) {
@@ -331,4 +343,8 @@ public class BpmnProcessDataEventListener
         }
         return unqualifiedClasses;
     }
+
+    public Set<String> getUniqueVariables() {
+        return uniqueVariables;
+    }
 }
