@@ -27,13 +27,23 @@ import org.apache.commons.lang3.StringUtils;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
 import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.EndErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveDatabasedGateway;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventThrowing;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventThrowing;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
 import org.kie.workbench.common.stunner.bpmn.definition.ReusableSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
+import org.kie.workbench.common.stunner.bpmn.definition.StartErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
@@ -44,12 +54,13 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.connectors.Prio
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.AssignmentsInfo;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.AdHoc;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.ProcessInstanceDescription;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.CancelActivity;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.IsInterrupting;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.SignalRef;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.TimeCycle;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.TimeCycleLanguage;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.TimeDate;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.TimeDuration;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.ErrorRef;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.MessageRef;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.SignalRef;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.SignalScope;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.TimerSettings;
 import org.kie.workbench.common.stunner.bpmn.definition.property.gateway.DefaultRoute;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.DistributionType;
@@ -147,14 +158,8 @@ public abstract class BaseOryxIdMappings implements OryxIdMappings {
                 "priority");
             put(ExclusiveDatabasedGateway.class,
                 "Exclusive_Databased_Gateway");
-            put(TimeDate.class,
-                "timedate");
-            put(TimeDuration.class,
-                "timeduration");
-            put(TimeCycle.class,
-                "timecycle");
-            put(TimeCycleLanguage.class,
-                "timecyclelanguage");
+            put(TimerSettings.class,
+                "timersettings");
             put(EmbeddedSubprocess.class,
                 "Subprocess");
             put(AdHoc.class,
@@ -183,6 +188,16 @@ public abstract class BaseOryxIdMappings implements OryxIdMappings {
                 "isinterrupting");
             put(SignalRef.class,
                 "signalref");
+            put(MessageRef.class,
+                "messageref");
+            put(CancelActivity.class,
+                "boundarycancelactivity");
+            put(SignalScope.class,
+                "signalscope");
+            put(ErrorRef.class,
+                "errorref");
+            put(IntermediateErrorEventCatching.class,
+                "IntermediateErrorEvent");
 
             // Simulation properties
             put(TimeUnit.class,
@@ -253,31 +268,87 @@ public abstract class BaseOryxIdMappings implements OryxIdMappings {
             startNoneEventPropertiesMap.put(AssignmentsInfo.class,
                                             "assignmentsinfo");
 
+            Map<Class<?>, String> endSignalEventPropertiesMap = new HashMap<Class<?>, String>();
+            put(EndSignalEvent.class,
+                endSignalEventPropertiesMap);
+            endSignalEventPropertiesMap.put(AssignmentsInfo.class,
+                                            "assignmentsinfo");
+
             Map<Class<?>, String> startSignalEventPropertiesMap = new HashMap<Class<?>, String>();
             put(StartSignalEvent.class,
                 startSignalEventPropertiesMap);
             startSignalEventPropertiesMap.put(AssignmentsInfo.class,
                                               "assignmentsinfo");
+
             Map<Class<?>, String> startTimerEventPropertiesMap = new HashMap<Class<?>, String>();
             put(StartTimerEvent.class,
                 startTimerEventPropertiesMap);
             startTimerEventPropertiesMap.put(AssignmentsInfo.class,
                                              "assignmentsinfo");
 
+            Map<Class<?>, String> startMessageEventPropertiesMap = new HashMap<Class<?>, String>();
+            put(StartMessageEvent.class,
+                startMessageEventPropertiesMap);
+            startMessageEventPropertiesMap.put(AssignmentsInfo.class,
+                                               "assignmentsinfo");
+
+            Map<Class<?>, String> startErrorEventPropertiesMap = new HashMap<Class<?>, String>();
+            put(StartErrorEvent.class,
+                startErrorEventPropertiesMap);
+            startErrorEventPropertiesMap.put(AssignmentsInfo.class,
+                                             "assignmentsinfo");
+
             Map<Class<?>, String> intermediateTimerEventPropertiesMap = new HashMap<Class<?>, String>();
             put(IntermediateTimerEvent.class,
                 intermediateTimerEventPropertiesMap);
             intermediateTimerEventPropertiesMap.put(AssignmentsInfo.class,
                                                     "assignmentsinfo");
 
+            Map<Class<?>, String> intermediateSignalEventCatchingPropertiesMap = new HashMap<Class<?>, String>();
+            put(IntermediateSignalEventCatching.class,
+                intermediateSignalEventCatchingPropertiesMap);
+            intermediateSignalEventCatchingPropertiesMap.put(AssignmentsInfo.class,
+                                                             "assignmentsinfo");
+
+            Map<Class<?>, String> intermediateErrorEventCatchingPropertiesMap = new HashMap<Class<?>, String>();
+            put(IntermediateErrorEventCatching.class,
+                intermediateErrorEventCatchingPropertiesMap);
+            intermediateErrorEventCatchingPropertiesMap.put(AssignmentsInfo.class,
+                                                            "assignmentsinfo");
+            Map<Class<?>, String> intermediateMessageEventCatchingPropertiesMap = new HashMap<Class<?>, String>();
+            put(IntermediateMessageEventCatching.class,
+                intermediateMessageEventCatchingPropertiesMap);
+            intermediateMessageEventCatchingPropertiesMap.put(AssignmentsInfo.class,
+                                                              "assignmentsinfo");
+
+            Map<Class<?>, String> intermediateSignalEventThrowingPropertiesMap = new HashMap<Class<?>, String>();
+            put(IntermediateSignalEventThrowing.class,
+                intermediateSignalEventThrowingPropertiesMap);
+            intermediateSignalEventThrowingPropertiesMap.put(AssignmentsInfo.class,
+                                                             "assignmentsinfo");
+
+            Map<Class<?>, String> intermediateMessageEventThrowingPropertiesMap = new HashMap<Class<?>, String>();
+            put(IntermediateMessageEventThrowing.class,
+                intermediateMessageEventThrowingPropertiesMap);
+            intermediateMessageEventThrowingPropertiesMap.put(AssignmentsInfo.class,
+                                                             "assignmentsinfo");
+
             Map<Class<?>, String> endEventPropertiesMap = new HashMap<Class<?>, String>();
             put(EndNoneEvent.class,
                 endEventPropertiesMap);
             put(EndTerminateEvent.class,
                 endEventPropertiesMap);
+            put(EndErrorEvent.class,
+                endEventPropertiesMap);
             endEventPropertiesMap.put(AssignmentsInfo.class,
                                       "assignmentsinfo");
 
+            Map<Class<?>, String> endMessageEventPropertiesMap = new HashMap<Class<?>, String>();
+            put(EndMessageEvent.class,
+                endMessageEventPropertiesMap);
+            endMessageEventPropertiesMap.put(AssignmentsInfo.class,
+                                             "assignmentsinfo");
+
             Map<Class<?>, String> reusableSubprocessPropertiesMap = new HashMap<Class<?>, String>();
             put(ReusableSubprocess.class,
                 reusableSubprocessPropertiesMap);
