@@ -48,9 +48,13 @@ import org.kie.workbench.common.stunner.bpmn.resource.BPMNDefinitionSetResourceT
 import org.uberfire.java.nio.file.Path;
 import org.uberfire.paging.PageResponse;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 public class BpmnFileIndexerTest extends BaseIndexingTest<BPMNDefinitionSetResourceType> {
 
@@ -92,13 +96,13 @@ public class BpmnFileIndexerTest extends BaseIndexingTest<BPMNDefinitionSetResou
     }
 
     private static final long WAIT_TIME_MILLIS = 2000;
-
     private static final int MAX_WAIT_TIMES = 8;
 
     @Test
     public void testBpmnIndexing() throws Exception {
 
         List<Path> pathList = new ArrayList<>();
+        ioService().startBatch(ioService().getFileSystem(basePath.toUri()));
         for (int i = 0; i < BPMN_FILES.length; ++i) {
             String bpmnFile = BPMN_FILES[i];
             if (bpmnFile.endsWith("bpmn")) {
@@ -109,6 +113,7 @@ public class BpmnFileIndexerTest extends BaseIndexingTest<BPMNDefinitionSetResou
                                   bpmnStr);
             }
         }
+        ioService().endBatch();
         Path[] paths = pathList.toArray(new Path[pathList.size()]);
 
         {
@@ -287,6 +292,6 @@ public class BpmnFileIndexerTest extends BaseIndexingTest<BPMNDefinitionSetResou
 
     @Override
     protected String getRepositoryName() {
-        return this.getClass().getSimpleName();
+        return testName.getMethodName();
     }
 }
