@@ -21,21 +21,30 @@ import javax.enterprise.context.ApplicationScoped;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.BPMNDiagramShapeDef;
+import org.kie.workbench.common.stunner.bpmn.client.shape.def.CatchingIntermediateEventShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.EndEventShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.GatewayShapeDef;
-import org.kie.workbench.common.stunner.bpmn.client.shape.def.IntermediateEventShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.LaneShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.SequenceFlowConnectorDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.StartEventShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.SubprocessShapeDef;
 import org.kie.workbench.common.stunner.bpmn.client.shape.def.TaskShapeDef;
+import org.kie.workbench.common.stunner.bpmn.client.shape.def.ThrowingIntermediateEventShapeDef;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
+import org.kie.workbench.common.stunner.bpmn.definition.EndErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EndMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.EndSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.ExclusiveDatabasedGateway;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventThrowing;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventThrowing;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.Lane;
 import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
@@ -43,6 +52,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.ParallelGateway;
 import org.kie.workbench.common.stunner.bpmn.definition.ReusableSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
 import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
+import org.kie.workbench.common.stunner.bpmn.definition.StartErrorEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
@@ -105,6 +116,12 @@ public class BPMNShapeFactory
                 .delegate(StartTimerEvent.class,
                           new StartEventShapeDef(),
                           () -> svgShapeFactory)
+                .delegate(StartMessageEvent.class,
+                          new StartEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(StartErrorEvent.class,
+                          new StartEventShapeDef(),
+                          () -> svgShapeFactory)
                 .delegate(ParallelGateway.class,
                           new GatewayShapeDef(),
                           () -> svgShapeFactory)
@@ -123,11 +140,35 @@ public class BPMNShapeFactory
                 .delegate(EndNoneEvent.class,
                           new EndEventShapeDef(),
                           () -> svgShapeFactory)
+                .delegate(EndSignalEvent.class,
+                          new EndEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(EndMessageEvent.class,
+                          new EndEventShapeDef(),
+                          () -> svgShapeFactory)
                 .delegate(EndTerminateEvent.class,
                           new EndEventShapeDef(),
                           () -> svgShapeFactory)
+                .delegate(EndErrorEvent.class,
+                          new EndEventShapeDef(),
+                          () -> svgShapeFactory)
                 .delegate(IntermediateTimerEvent.class,
-                          new IntermediateEventShapeDef(),
+                          new CatchingIntermediateEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(IntermediateSignalEventCatching.class,
+                          new CatchingIntermediateEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(IntermediateErrorEventCatching.class,
+                          new CatchingIntermediateEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(IntermediateMessageEventCatching.class,
+                          new CatchingIntermediateEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(IntermediateSignalEventThrowing.class,
+                          new ThrowingIntermediateEventShapeDef(),
+                          () -> svgShapeFactory)
+                .delegate(IntermediateMessageEventThrowing.class,
+                          new ThrowingIntermediateEventShapeDef(),
                           () -> svgShapeFactory)
                 .delegate(SequenceFlow.class,
                           new SequenceFlowConnectorDef(),
