@@ -17,6 +17,7 @@ package org.kie.workbench.common.stunner.cm.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
@@ -35,11 +36,9 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Rect
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Category;
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
 import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
@@ -62,12 +61,6 @@ public class CaseManagementDiagram implements BPMNDiagram {
     @Category
     public static final transient String category = Categories.CONTAINERS;
 
-    @Title
-    public static final transient String title = "BPMN Diagram";
-
-    @Description
-    public static final transient String description = "BPMN Diagram";
-
     @PropertySet
     @FormField
     @Valid
@@ -98,22 +91,13 @@ public class CaseManagementDiagram implements BPMNDiagram {
     @NonPortable
     public static class CaseManagementDiagramBuilder implements Builder<CaseManagementDiagram> {
 
-        public static final transient String COLOR = "#FFFFFF";
-        public static final transient String BORDER_COLOR = "#000000";
-        public static final Double BORDER_SIZE = 1d;
-        public static final Double WIDTH = 950d;
-        public static final Double HEIGHT = 950d;
-
         @Override
         public CaseManagementDiagram build() {
             return new CaseManagementDiagram(new DiagramSet(""),
                                              new ProcessData(),
-                                             new BackgroundSet(COLOR,
-                                                               BORDER_COLOR,
-                                                               BORDER_SIZE),
+                                             new BackgroundSet(),
                                              new FontSet(),
-                                             new RectangleDimensionsSet(WIDTH,
-                                                                        HEIGHT));
+                                             new RectangleDimensionsSet());
         }
     }
 
@@ -136,15 +120,6 @@ public class CaseManagementDiagram implements BPMNDiagram {
         return category;
     }
 
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
-    public String getDescription() {
-        return description;
-    }
-
     public Set<String> getLabels() {
         return labels;
     }
