@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.cm.definition;
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
@@ -37,9 +38,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGen
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.ReusableSubprocessTaskExecutionSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.definition.annotation.definition.Title;
+import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
@@ -56,12 +56,6 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 // and it leads to the same errors).
 public class ReusableSubprocess extends BaseSubprocess implements DataIOModel {
 
-    @Title
-    public static final transient String title = "Reusable Sub-Process";
-
-    @Description
-    public static final transient String description = "A reusable Sub-Process. It can be used to invoke another process.";
-
     @PropertySet
     @FormField(
             afterElement = "general"
@@ -77,7 +71,7 @@ public class ReusableSubprocess extends BaseSubprocess implements DataIOModel {
     protected DataIOSet dataIOSet;
 
     @NonPortable
-    public static class ReusableSubprocessBuilder extends BaseSubprocessBuilder<ReusableSubprocess> {
+    public static class ReusableSubprocessBuilder implements Builder<ReusableSubprocess> {
 
         @Override
         public ReusableSubprocess build() {
@@ -85,12 +79,9 @@ public class ReusableSubprocess extends BaseSubprocess implements DataIOModel {
                     new BPMNGeneralSet("Subprocess"),
                     new ReusableSubprocessTaskExecutionSet(),
                     new DataIOSet(),
-                    new BackgroundSet(COLOR,
-                                      BORDER_COLOR,
-                                      BORDER_SIZE),
+                    new BackgroundSet(),
                     new FontSet(),
-                    new RectangleDimensionsSet(WIDTH,
-                                               HEIGHT),
+                    new RectangleDimensionsSet(),
                     new SimulationSet());
         }
     }
@@ -151,11 +142,6 @@ public class ReusableSubprocess extends BaseSubprocess implements DataIOModel {
         return false;
     }
 
-    @Override
-    public String getTitle() {
-        return title;
-    }
-
     public ReusableSubprocessTaskExecutionSet getExecutionSet() {
         return executionSet;
     }
