@@ -17,18 +17,18 @@ package org.kie.workbench.common.stunner.cm.client.canvas.controls.containment;
 
 import java.util.Optional;
 import java.util.function.Function;
+
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import com.ait.lienzo.client.core.shape.wires.IContainmentAcceptor;
-import com.ait.lienzo.client.core.shape.wires.ILayoutHandler;
 import com.ait.lienzo.client.core.shape.wires.WiresContainer;
 import com.ait.lienzo.client.core.shape.wires.WiresShape;
-import com.ait.lienzo.client.core.types.Point2D;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.controls.AbstractAcceptorControl;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresUtils;
 import org.kie.workbench.common.stunner.cm.client.command.CaseManagementCanvasCommandFactory;
+import org.kie.workbench.common.stunner.cm.client.wires.AbstractCaseManagementShape;
 import org.kie.workbench.common.stunner.cm.client.wires.CaseManagementContainmentStateHolder;
 import org.kie.workbench.common.stunner.cm.qualifiers.CaseManagementEditor;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
@@ -36,8 +36,8 @@ import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
-import org.kie.workbench.common.stunner.core.command.CompositeCommand;
-import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
+import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
+import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -48,7 +48,7 @@ import org.kie.workbench.common.stunner.core.graph.content.relationship.Child;
 public class CaseManagementContainmentAcceptorControlImpl extends AbstractAcceptorControl
         implements ContainmentAcceptorControl<AbstractCanvasHandler> {
 
-    private final IContainmentAcceptor CONTAINMENT_ACCEPTOR = new CanvasManagementContainmentAcceptor();
+    final IContainmentAcceptor CONTAINMENT_ACCEPTOR = new CanvasManagementContainmentAcceptor();
 
     private final CaseManagementCanvasCommandFactory canvasCommandFactory;
     private final CaseManagementContainmentStateHolder state;
@@ -72,44 +72,43 @@ public class CaseManagementContainmentAcceptorControlImpl extends AbstractAccept
 
     @Override
     public boolean allow(final Element parent,
-                         final Node child) {
+                         final Node[] children) {
         return evaluate(parent,
-                        child,
+                        children,
                         command -> getCommandManager().allow(getCanvasHandler(),
                                                              command));
     }
 
     @Override
     public boolean accept(final Element parent,
-                          final Node child) {
+                          final Node[] children) {
         throw new UnsupportedOperationException();
     }
 
     private boolean evaluate(final Element parent,
-                             final Node child,
+                             final Node[] children,
                              final Function<Command<AbstractCanvasHandler, CanvasViolation>, CommandResult<CanvasViolation>> executor) {
-        if (parent == null && child == null) {
+        if (parent == null && (children == null || children.length == 0)) {
             return false;
         }
+        final Node child = children[0];
         final Optional<Edge<?, Node>> edge = getFirstIncomingEdge(child,
                                                                   e -> e.getContent() instanceof Child);
         if (edge.isPresent()) {
-            final CompositeCommand<AbstractCanvasHandler, CanvasViolation> command = buildCommands(parent,
-                                                                                                   child,
-                                                                                                   edge.get());
+            final Command<AbstractCanvasHandler, CanvasViolation> command = buildCommands(parent,
+                                                                                          child,
+                                                                                          edge.get());
             final CommandResult<CanvasViolation> result = executor.apply(command);
-            return isCommandSuccess(child,
-                                    result);
+            return isCommandSuccess(result);
         }
         return true;
     }
 
-    private CompositeCommand<AbstractCanvasHandler, CanvasViolation> buildCommands(final Element parent,
-                                                                                   final Node child,
-                                                                                   final Edge edge) {
-        final CompositeCommandImpl.CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation> builder =
-                new CompositeCommandImpl
-                        .CompositeCommandBuilder<AbstractCanvasHandler, CanvasViolation>()
+    private Command<AbstractCanvasHandler, CanvasViolation> buildCommands(final Element parent,
+                                                                          final Node child,
+                                                                          final Edge edge) {
+        final CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation> builder =
+                new CompositeCommand.Builder<AbstractCanvasHandler, CanvasViolation>()
                         .reverse();
         if (null != edge.getSourceNode()) {
             builder.addCommand(
@@ -154,7 +153,8 @@ public class CaseManagementContainmentAcceptorControlImpl extends AbstractAccept
 
         @Override
         public boolean containmentAllowed(final WiresContainer wiresContainer,
-                                          final WiresShape wiresShape) {
+                                          final WiresShape[] wiresShapes) {
+            final WiresShape wiresShape = wiresShapes[0];
             if (!isWiresViewAccept(wiresContainer,
                                    wiresShape)) {
                 return false;
@@ -164,73 +164,33 @@ public class CaseManagementContainmentAcceptorControlImpl extends AbstractAccept
             final Node parentNode = WiresUtils.getNode(getCanvasHandler(),
                                                        wiresContainer);
             return allow(parentNode,
-                         childNode);
+                         new Node[]{childNode});
         }
 
         @Override
         public boolean acceptContainment(final WiresContainer wiresContainer,
-                                         final WiresShape wiresShape) {
-            // Check containment is allowed. This (almost) replicates AbstractContainmentBasedControl.accept()
-            // No need to checked whether a Child can be removed from a Container.
-            final boolean isAccept = containmentAllowed(wiresContainer,
-                                                        wiresShape);
-
-            // We have some interesting fun here; "accept" is called before the child WiresShape has been
-            // added to the parent WiresShape or in the correct position (index) as determined by the parent's
-            // ILayoutHandler. We therefore delay execution of the Command to mutate the Graph until the
-            // WiresContainer has completed positioning the child.
-            if (isAccept) {
-                wiresContainer.setLayoutHandler(new InterceptingLayoutHandler(wiresContainer));
-            }
-            return isAccept;
-        }
-    }
-
-    class InterceptingLayoutHandler implements ILayoutHandler {
-
-        private final WiresContainer container;
-        private final ILayoutHandler layout;
-
-        private InterceptingLayoutHandler(final WiresContainer container) {
-            this.container = container;
-            this.layout = container.getLayoutHandler();
-        }
-
-        @Override
-        public void add(final WiresShape shape,
-                        final WiresContainer container,
-                        final Point2D mouseRelativeLoc) {
-            try {
-
-                this.layout.add(shape,
-                                container,
-                                mouseRelativeLoc);
-
-                final WiresContainer newContainer = shape.getParent();
-                final Optional<Integer> newIndex = Optional.of(newContainer.getChildShapes().toList().indexOf(shape));
-                final Optional<WiresContainer> originalContainer = state.getOriginalParent();
-                final Optional<Integer> originalIndex = state.getOriginalIndex();
-
-                getCommandManager().execute(getCanvasHandler(),
-                                            makeAddMutationCommand(shape,
-                                                                   newContainer,
-                                                                   newIndex,
-                                                                   originalContainer,
-                                                                   originalIndex));
-            } finally {
-                this.container.setLayoutHandler(layout);
-            }
-        }
-
-        @Override
-        public void remove(final WiresShape shape,
-                           final WiresContainer container) {
-            try {
-                this.layout.remove(shape,
-                                   container);
-            } finally {
-                this.container.setLayoutHandler(layout);
+                                         final WiresShape[] wiresShapes) {
+            if (state.getGhost().isPresent() &&
+                    containmentAllowed(wiresContainer,
+                                       wiresShapes)) {
+                final AbstractCaseManagementShape container = (AbstractCaseManagementShape) wiresContainer;
+                final AbstractCaseManagementShape ghost = state.getGhost().get();
+                final int index = container.getIndex(ghost);
+                if (index >= 0) {
+                    final Optional<Integer> newIndex = Optional.of(index);
+                    final Optional<WiresContainer> originalContainer = state.getOriginalParent();
+                    final Optional<Integer> originalIndex = state.getOriginalIndex();
+                    final CommandResult<CanvasViolation> result =
+                            getCommandManager().execute(getCanvasHandler(),
+                                                        makeAddMutationCommand(wiresShapes[0],
+                                                                               wiresContainer,
+                                                                               newIndex,
+                                                                               originalContainer,
+                                                                               originalIndex));
+                    return !CommandUtils.isError(result);
+                }
             }
+            return false;
         }
 
         protected Command<AbstractCanvasHandler, CanvasViolation> makeAddMutationCommand(final WiresShape shape,
@@ -252,15 +212,5 @@ public class CaseManagementContainmentAcceptorControlImpl extends AbstractAccept
                                      originalParent,
                                      originalIndex);
         }
-
-        @Override
-        public void requestLayout(final WiresContainer container) {
-            this.layout.requestLayout(container);
-        }
-
-        @Override
-        public void layout(final WiresContainer container) {
-            this.layout.layout(container);
-        }
     }
 }
