@@ -20,7 +20,6 @@ import java.util.function.Consumer;
 
 import com.ait.lienzo.client.core.shape.Layer;
 import com.ait.lienzo.client.core.shape.wires.WiresManager;
-import com.ait.lienzo.client.core.shape.wires.handlers.WiresControlFactory;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
@@ -41,16 +40,21 @@ import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.Edge
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.ElementBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.NodeBuilderControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.impl.EdgeBuilderControlImpl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.ClipboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.clipboard.LocalClipboardControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControlImpl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.pan.PanControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
 import org.mockito.Mock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertNotNull;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class CaseManagementCanvasFactoryTest {
@@ -65,12 +69,11 @@ public class CaseManagementCanvasFactoryTest {
     private ManagedInstance<EdgeBuilderControl> edgeBuilderControls;
     private ManagedInstance<ZoomControl> zoomControls;
     private ManagedInstance<PanControl> panControls;
+    private ManagedInstance<KeyboardControl> keyboardControls;
+    private ManagedInstance<ClipboardControl> clipboardControls;
     private ManagedInstance<AbstractCanvas> canvasInstances;
     private ManagedInstance<AbstractCanvasHandler> canvasHandlerInstances;
 
-    @Mock
-    private WiresControlFactory caseManagementControlFactory;
-
     @Mock
     private Layer layer;
 
@@ -93,6 +96,8 @@ public class CaseManagementCanvasFactoryTest {
         this.edgeBuilderControls = mockManagedInstance(EdgeBuilderControlImpl.class);
         this.zoomControls = mockManagedInstance(ZoomWheelControlImpl.class);
         this.panControls = mockManagedInstance(PanControlImpl.class);
+        this.keyboardControls = mockManagedInstance(KeyboardControlImpl.class);
+        this.clipboardControls = mockManagedInstance(LocalClipboardControl.class);
         this.canvasInstances = mockManagedInstance(CaseManagementCanvasPresenter.class,
                                                    (c) -> when(c.getWiresManager()).thenReturn(wiresManager));
         this.canvasHandlerInstances = mockManagedInstance(CaseManagementCanvasHandler.class);
@@ -107,12 +112,45 @@ public class CaseManagementCanvasFactoryTest {
                                                        edgeBuilderControls,
                                                        zoomControls,
                                                        panControls,
+                                                       keyboardControls,
+                                                       clipboardControls,
                                                        canvasInstances,
-                                                       canvasHandlerInstances,
-                                                       caseManagementControlFactory);
+                                                       canvasHandlerInstances);
         factory.init();
     }
 
+    @Test
+    public void testControls() {
+        ConnectionAcceptorControl connectionAcceptorControl = factory.newControl(ConnectionAcceptorControl.class);
+        assertNotNull(connectionAcceptorControl);
+        ContainmentAcceptorControl containmentAcceptorControl = factory.newControl(ContainmentAcceptorControl.class);
+        assertNotNull(containmentAcceptorControl);
+        DockingAcceptorControl dockingAcceptorControl = factory.newControl(DockingAcceptorControl.class);
+        assertNotNull(dockingAcceptorControl);
+        CanvasInPlaceTextEditorControl canvasInPlaceTextEditorControl = factory.newControl(CanvasInPlaceTextEditorControl.class);
+        assertNotNull(canvasInPlaceTextEditorControl);
+        SelectionControl selectionControl = factory.newControl(SelectionControl.class);
+        assertNotNull(selectionControl);
+        ElementBuilderControl elementBuilderControl = factory.newControl(ElementBuilderControl.class);
+        assertNotNull(elementBuilderControl);
+        NodeBuilderControl nodeBuilderControl = factory.newControl(NodeBuilderControl.class);
+        assertNotNull(nodeBuilderControl);
+        EdgeBuilderControl edgeBuilderControl = factory.newControl(EdgeBuilderControl.class);
+        assertNotNull(edgeBuilderControl);
+        ZoomControl zoomControl = factory.newControl(ZoomControl.class);
+        assertNotNull(zoomControl);
+        PanControl panControl = factory.newControl(PanControl.class);
+        assertNotNull(panControl);
+        KeyboardControl keyboardControl = factory.newControl(KeyboardControl.class);
+        assertNotNull(keyboardControl);
+    }
+
+    @Test
+    public void testCanvases() {
+        assertNotNull(factory.newCanvas());
+        assertNotNull(factory.newCanvasHandler());
+    }
+
     @SuppressWarnings("unchecked, unused")
     private <T, C extends T> ManagedInstance<T> mockManagedInstance(final Class<C> concrete) {
         return mockManagedInstance(concrete,
@@ -124,16 +162,10 @@ public class CaseManagementCanvasFactoryTest {
                                                                     final Consumer<C> setup) {
         final C mock = mock(concrete);
         final ManagedInstance<T> managedInstance = mock(ManagedInstance.class);
+        when(managedInstance.isAmbiguous()).thenReturn(false);
+        when(managedInstance.isUnsatisfied()).thenReturn(false);
         when(managedInstance.get()).thenReturn(mock);
         setup.accept(mock);
         return managedInstance;
     }
-
-    @Test
-    public void checkCanvasHasWiresControlFactorySet() {
-        factory.newCanvas();
-
-        assertEquals(wiresManager.getControlFactory(),
-                     caseManagementControlFactory);
-    }
 }
