@@ -22,6 +22,7 @@ import java.util.Set;
 import org.hamcrest.BaseMatcher;
 import org.hamcrest.Description;
 import org.jboss.errai.common.client.api.Caller;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -78,9 +79,14 @@ import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.CallerMock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.anyObject;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.argThat;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class CaseManagementDefinitionSetPaletteBuilderImplTest {
@@ -109,7 +115,7 @@ public class CaseManagementDefinitionSetPaletteBuilderImplTest {
     private ShapeManager shapeManager;
 
     @Mock
-    private BS3PaletteWidget palette;
+    private ManagedInstance<BS3PaletteWidget<DefinitionSetPalette>> palette;
 
     @Mock
     private DefinitionManager definitionManager;
