@@ -17,17 +17,19 @@ package org.kie.workbench.common.widgets.metadata.client;
 
 import java.lang.reflect.Field;
 
-import org.drools.workbench.models.datamodel.imports.Imports;
 import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.context.ProjectContext;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.junit.Before;
+import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -84,6 +86,10 @@ abstract class KieMultipleDocumentEditorTestBase {
     @Mock
     protected DefaultFileNameValidator fileNameValidator;
 
+    @Spy
+    @InjectMocks
+    protected AssetUpdateValidator assetUpdateValidator;
+
     @Mock
     protected MenuItem saveMenuItem;
 
@@ -170,6 +176,7 @@ abstract class KieMultipleDocumentEditorTestBase {
         wrapped.setRegisteredDocumentsMenuBuilder(registeredDocumentsMenuBuilder);
         wrapped.setFileMenuBuilder(fileMenuBuilder);
         wrapped.setFileNameValidator(fileNameValidator);
+        wrapped.setAssetUpdateValidator(assetUpdateValidator);
 
         this.editor = spy(wrapped);
 
